@@ -210,6 +210,8 @@ public slots:
 	void setMaxFps(float m) {maxfps = qMax(m, minfps); StelApp::immediateSave("video/maximum_fps", m); emit maxFpsChanged(maxfps);}
 	//! Get the current maximum frames per second.
 	float getMaxFps() const {return maxfps;}
+	//! Get the desired frame rate: a number in [minfps, maxfps]
+	float getDesiredFps() const { return needsMaxFPS() ? maxfps : minfps; }
 	//! Set the minimum time between frames (in milliseconds).
 	//! @param m the new setting.
 	void setMinTimeBetweenFrames(int m) {minTimeBetweenFrames = qMax(0, m); StelApp::immediateSave("video/min_time_between_frames", minTimeBetweenFrames); emit minTimeBetweenFramesChanged(minTimeBetweenFrames);}
@@ -286,6 +288,15 @@ private slots:
 	void fpsTimerUpdate();
 	void hideCursor();
 
+	//! Set inhibiting triggering screensaver/power save on entering fullscreen mode.
+	//! Connected via QTimer.
+	//! Activate via CLI flag --no-screensaver (or -F)
+	//! @note This is currently available on Windows only.
+	void disableScreensaver(bool fullscreen);
+	//! send OS signal to inhibit triggering screensaver/power save. (Connected via QTimer.)
+	//! @note This is currently working on Windows only.
+	void bumpScreensaver();
+
 #ifdef OPENGL_DEBUG_LOGGING
 	void logGLMessage(const QOpenGLDebugMessage& debugMessage);
 	void contextDestroyed();
@@ -303,7 +314,7 @@ private:
 	//! to provide feedback to the user about bad OpenGL drivers.
 	void processOpenGLdiagnosticsAndWarnings(QSettings *conf, QOpenGLContext* context) const;
 	//! Get physical dimensions given the virtual dimensions for the screen where this window is located.
-	QRectF getPhysicalSize(const QRectF& virtualRect) const;
+	QRectF getPhysicalSize(const QRectF& virtualRect) const;	
 
 	//! The StelMainView singleton
 	static StelMainView* singleton;
@@ -352,6 +363,9 @@ private:
 	int minTimeBetweenFrames;
 	QTimer* fpsTimer;
 
+	//! A timer that resets the screensaver when CLI option --no-screensaver (or -F) is given.
+	QTimer* screensaverInhibitorTimer;
+
 #ifdef OPENGL_DEBUG_LOGGING
 	QOpenGLDebugLogger* glLogger;
 #endif
