@@ -37,6 +37,7 @@
 #ifdef Q_OS_LINUX
 #include <sys/types.h>
 #include <sys/sysinfo.h>
+#include <cstdint>
 #endif
 
 // all BSD systems
@@ -87,7 +88,7 @@ void printSystemInfo()
         log(QString("Addressing mode: %1").arg(StelUtils::getAddressingMode()));
 
 	// write CPU and memory info
-	log(QString("Processor architecture: %1").arg(QSysInfo::currentCpuArchitecture()));
+        log(QString("CPU architecture: %1").arg(QSysInfo::currentCpuArchitecture()));
 
 #ifdef Q_OS_WIN
 	// Use WMI
@@ -121,13 +122,13 @@ void printSystemInfo()
 					break;
 
 				hr = obj->Get(L"Name", 0, &vt_prop, nullptr, nullptr);
-				log(QString("Processor name: %1").arg(vt_prop.bstrVal));
+                                log(QString("CPU name: %1").arg(vt_prop.bstrVal));
 
 				hr = obj->Get(L"MaxClockSpeed", 0, &vt_prop, nullptr, nullptr);
-				log(QString("Processor maximum speed: %1 MHz").arg(vt_prop.uintVal));
+                                log(QString("CPU maximum speed: %1 MHz").arg(vt_prop.uintVal));
 
 				hr = obj->Get(L"NumberOfLogicalProcessors", 0, &vt_prop, nullptr, nullptr);
-				log(QString("Processor logical cores: %1").arg(vt_prop.intVal));
+                                log(QString("CPU logical cores: %1").arg(vt_prop.intVal));
 
 				VariantClear(&vt_prop);
 				obj->Release();
@@ -151,8 +152,8 @@ void printSystemInfo()
 			}
 			log(QString("Total physical memory: %1 MB").arg(totalRAM/(1024<<10)));
 
-			// GPU info
-			const std::wstring gpu_query(L"SELECT Name, AdapterRAM, CurrentHorizontalResolution, CurrentVerticalResolution FROM Win32_VideoController");
+			// GPU info (Enabled only)
+			const std::wstring gpu_query(L"SELECT Name, AdapterRAM, CurrentHorizontalResolution, CurrentVerticalResolution FROM Win32_VideoController WHERE Status='OK'");
 			service->ExecQuery(bstr_t(L"WQL"), bstr_t(std::wstring(gpu_query.begin(), gpu_query.end()).c_str()), WBEM_FLAG_FORWARD_ONLY | WBEM_FLAG_RETURN_IMMEDIATELY, nullptr, &enumerator);
 			while (enumerator)
 			{
@@ -161,10 +162,10 @@ void printSystemInfo()
 					break;
 
 				hr = obj->Get(L"Name", 0, &vt_prop, nullptr, nullptr);
-				log(QString("Video controller name: %1").arg(vt_prop.bstrVal));
+                                log(QString("GPU name: %1").arg(vt_prop.bstrVal));
 
 				hr = obj->Get(L"AdapterRAM", 0, &vt_prop, nullptr, nullptr);
-				log(QString("Video controller RAM: %1 MB").arg(vt_prop.ullVal/(1024<<10)));
+                                log(QString("GPU RAM: %1 MB").arg(vt_prop.ullVal/(1024<<10)));
 
 				hr = obj->Get(L"CurrentHorizontalResolution", 0, &vt_prop, nullptr, nullptr);
 				int currHRes = vt_prop.intVal;
@@ -184,22 +185,37 @@ void printSystemInfo()
 #endif
 
 #ifdef Q_OS_MACOS
+	// CPU info
 	size_t size = 0;
 	sysctlbyname("machdep.cpu.brand_string", nullptr, &size, nullptr, 0);
 	std::string cpuname(size, '\0');
 	sysctlbyname("machdep.cpu.brand_string", const_cast<char *>(cpuname.data()), &size, nullptr, 0);
-	log(QString("Processor name: %1").arg(cpuname.data()));
+        log(QString("CPU name: %1").arg(cpuname.data()));
 
 	int64_t maxFreq = 0;
 	size = sizeof(maxFreq);
 	if (sysctlbyname("hw.cpufrequency_max", &maxFreq, &size, nullptr, 0) != -1)
-		log(QString("Processor maximum speed: %1 MHz").arg(maxFreq/1000000));
+                log(QString("CPU maximum speed: %1 MHz").arg(maxFreq/1000000));
+	else
+	{
+		// Apple Silicon case
+		int64_t tbFreq = 0;
+		size = sizeof(tbFreq);
+		sysctlbyname("hw.tbfrequency", &tbFreq, &size, nullptr, 0);
+
+		struct clockinfo clockinfo;
+		size = sizeof(clockinfo);
+		sysctlbyname("kern.clockrate", &clockinfo, &size, nullptr, 0);
+
+		log(QString("CPU maximum speed: %1 MHz").arg((tbFreq*clockinfo.hz)/1000000));
+	}
 
 	int ncpu = 0;
 	size = sizeof(ncpu);
 	sysctlbyname("hw.ncpu", &ncpu, &size, nullptr, 0);
-	log(QString("Processor logical cores: %1").arg(ncpu));
+        log(QString("CPU logical cores: %1").arg(ncpu));
 
+	// RAM info
 	uint64_t totalRAM = 0;
 	size = sizeof(totalRAM);
 	sysctlbyname("hw.memsize", &totalRAM, &size, nullptr, 0);
@@ -214,16 +230,20 @@ void printSystemInfo()
 
 #ifdef Q_OS_LINUX
 	// CPU info
-	QString cpumodel = "unknown", hardware = "", model = "";
+	QString cpumodel = "unknown", freq = "", hardware = "", model = "", platform = "", machine = "", vendor = "", systype = "";
 	int ncpu = 0;
 	bool cpuOK = false;
+	bool readVendorId = false;
 	QFile infoFile("/proc/cpuinfo");
 	if (!infoFile.open(QIODevice::ReadOnly | QIODevice::Text))
 		log("Could not get CPU info.");
 	else
 	{
 		cpuOK = true;
-		bool readModel = true;
+		bool readCpuModel = true;
+                #if defined(__powerpc__) || defined(__powerpc64__)
+		bool readClock = true;
+                #endif
 		while(!infoFile.peek(1).isEmpty())
 		{
 			QString line = infoFile.readLine();
@@ -231,39 +251,94 @@ void printSystemInfo()
 			if (line.startsWith("processor", Qt::CaseInsensitive))
 				ncpu++;
 
-			if (line.startsWith("model name", Qt::CaseInsensitive) && readModel)
+			if (line.startsWith("model name", Qt::CaseInsensitive) && readCpuModel)
 			{
 				cpumodel = line.split(":").last().trimmed();
-				readModel = false;
+				readCpuModel = false;
 			}
+			#if defined(__powerpc__) || defined(__powerpc64__)
+			if (line.startsWith("cpu", Qt::CaseInsensitive) && readCpuModel)
+			{
+				cpumodel = line.split(":").last().trimmed();
+				readCpuModel = false;
+			}
+			if (line.startsWith("clock", Qt::CaseInsensitive) && readClock)
+			{
+				double frequency = line.split(":").last().trimmed().replace("MHz", "").toDouble();
+				freq = QString("%1 MHz").arg(QString::number(qRound(frequency)));
+				readClock = false;
+			}
+			#endif
+                        #if defined(__e2k__) || defined(__s390__) || defined(__s390x__)
+			if (line.startsWith("vendor_id", Qt::CaseInsensitive) && !readVendorId)
+			{
+				vendor = line.split(":").last().trimmed();
+				readVendorId = true;
+			}
+                        #endif
+                        #if defined(__aarch64__) || defined(__arm__)
+			if (line.startsWith("Processor", Qt::CaseSensitive) && readCpuModel)
+			{
+				cpumodel = line.split(":").last().trimmed();
+				readCpuModel = false;
+			}
+                        #endif
+                        #if defined(__mips__)
+			if (line.startsWith("cpu model", Qt::CaseSensitive) && readCpuModel)
+			{
+				cpumodel = line.split(":").last().trimmed();
+				readCpuModel = false;
+			}
+                        #endif
+
+			// for PowerPC/MIPS computers
+			if (line.startsWith("platform", Qt::CaseInsensitive))
+				platform = line.split(":").last().trimmed();
+			if (line.startsWith("machine", Qt::CaseInsensitive))
+				machine = line.split(":").last().trimmed();
 
 			// for ARM-devices, such Raspberry Pi
 			if (line.startsWith("hardware", Qt::CaseInsensitive))
 				hardware = line.split(":").last().trimmed();
-			if (line.startsWith("model", Qt::CaseInsensitive) && !hardware.isEmpty())
+			if (line.startsWith("model", Qt::CaseInsensitive))
 				model = line.split(":").last().trimmed();
+
+			// for MIPS computers
+			if (line.startsWith("system type", Qt::CaseInsensitive))
+				systype = line.split(":").last().trimmed();
 		}
 		infoFile.close();
 	}
 
-	QString freq = "unknown";
 	infoFile.setFileName("/sys/devices/system/cpu/cpu0/cpufreq/cpuinfo_max_freq");
 	if (infoFile.open(QIODevice::ReadOnly | QIODevice::Text))
 	{
 		// frequency in kHz: https://www.kernel.org/doc/Documentation/cpu-freq/user-guide.txt
-		freq = QString::number( infoFile.readAll().toInt()/1000);
+		freq = QString("%1 MHz").arg(QString::number( infoFile.readAll().toInt()/1000));
 		infoFile.close();
 	}
 
 	if (cpuOK)
 	{
-		log(QString("Processor name: %1").arg(cpumodel));
+		if (readVendorId)
+			log(QString("CPU name: %1 %2").arg(vendor, cpumodel));
+		else if (cpumodel!=L1S("unknown"))
+			log(QString("CPU name: %1").arg(cpumodel));
+		if (!freq.isEmpty())
+			log(QString("CPU maximum speed: %1").arg(freq));
+
+		log(QString("CPU logical cores: %1").arg(ncpu));
+
 		if (!hardware.isEmpty())
-			log(QString("Processor hardware: %1").arg(hardware));
+			log(QString("CPU hardware: %1").arg(hardware));
+		if (!systype.isEmpty())
+			log(QString("System type: %1").arg(systype));
+		if (!platform.isEmpty())
+			log(QString("Platform: %1").arg(platform));
 		if (!model.isEmpty())
-			log(QString("Device model: %1").arg(model));
-		log(QString("Processor maximum speed: %1 MHz").arg(freq));
-		log(QString("Processor logical cores: %1").arg(ncpu));
+			log(QString("Model: %1").arg(model));
+		if (!machine.isEmpty())
+			log(QString("Machine: %1").arg(machine));
 	}
 
 	// memory info
@@ -294,17 +369,25 @@ void printSystemInfo()
 	sysctlbyname(_model, nullptr, &len, nullptr, 0);
 	std::string model(len, '\0');
 	sysctlbyname(_model, const_cast<char *>(model.data()), &len, nullptr, 0);
-	log(QString("Processor name: %1").arg(model.data()));
+	log(QString("CPU name: %1").arg(model.data()));
 
 	int64_t freq = 0;
 	len = sizeof(freq);
-	sysctlbyname("machdep.tsc_freq", &freq, &len, nullptr, 0);
-	log(QString("Processor speed: %1 MHz").arg(freq/1000000));
+	if (sysctlbyname("machdep.tsc_freq", &freq, &len, nullptr, 0) != -1)
+		log(QString("CPU speed: %1 MHz").arg(freq/1000000)); // FreeBSD and NetBSD (i386/amd64 by default)
+	else if (sysctlbyname("hw.clockrate", &freq, &len, nullptr, 0) != -1)
+		log(QString("CPU speed: %1 MHz").arg(freq)); // FreeBSD/amd64
+	else if (sysctlbyname("hw.freq.cpu", &freq, &len, nullptr, 0) != -1)
+		log(QString("CPU speed: %1 MHz").arg(freq)); // FreeBSD/sparc64
+	else if (sysctlbyname("dev.cpu.0.freq", &freq, &len, nullptr, 0) != -1)
+		log(QString("CPU speed: %1 MHz").arg(freq)); // FreeBSD/powerpc64
+	else if (sysctlbyname("hw.cpu0.clock_frequency", &freq, &len, nullptr, 0) != -1)
+		log(QString("CPU speed: %1 MHz").arg(freq/1000000)); // NetBSD/sparc64
 
 	int ncpu = 0;
 	len = sizeof(ncpu);
 	sysctlbyname("hw.ncpu", &ncpu, &len, nullptr, 0);
-	log(QString("Processor logical cores: %1").arg(ncpu));
+	log(QString("CPU logical cores: %1").arg(ncpu));
 
 	// memory info
 	uint64_t totalRAM = 0;
@@ -316,27 +399,29 @@ void printSystemInfo()
 #ifdef Q_OS_OPENBSD
 	int mib[2], freq, ncpu;
 	size_t len = 1024;
-	std::string model;
+	std::string model, vendor, machine;
 	model.resize(len);
+	vendor.resize(len);
+	machine.resize(len);
 
 	// CPU info
 	mib[0] = CTL_HW;
 	mib[1] = HW_MODEL;
 	sysctl(mib, 2, model.data(), &len, NULL, 0);
 	model.resize(len);
-	log(QString("Processor name: %1").arg(model.data()));
+	log(QString("CPU name: %1").arg(model.data()));
 
 	mib[0] = CTL_HW;
 	mib[1] = HW_CPUSPEED;
 	len = sizeof(freq);
 	sysctl(mib, 2, &freq, &len, NULL, 0);
-	log(QString("Processor speed: %1 MHz").arg(freq));
+	log(QString("CPU speed: %1 MHz").arg(freq));
 
 	mib[0] = CTL_HW;
 	mib[1] = HW_NCPU;
 	len = sizeof(ncpu);
 	sysctl(mib, 2, &ncpu, &len, NULL, 0);
-	log(QString("Processor logical cores: %1").arg(ncpu));
+	log(QString("CPU logical cores: %1").arg(ncpu));
 
 	// memory info
 	mib[0] = CTL_HW;
@@ -349,16 +434,35 @@ void printSystemInfo()
 	len = sizeof(totalRAM);
 	sysctl(mib, 2, &totalRAM, &len, NULL, 0);
 	log(QString("Total physical memory: %1 MB").arg(totalRAM/(1024<<10)));
+
+	// extra info
+	mib[0] = CTL_HW;
+	mib[1] = HW_VENDOR;
+	len = 1024;
+	sysctl(mib, 2, vendor.data(), &len, NULL, 0);
+	vendor.resize(len);
+	QString sVendor = QString("%1").arg(vendor.data()).trimmed();
+	if (!sVendor.isEmpty())
+		log(QString("Vendor: %1").arg(sVendor));
+
+	mib[0] = CTL_HW;
+	mib[1] = HW_PRODUCT;
+	len = 1024;
+	sysctl(mib, 2, machine.data(), &len, NULL, 0);
+	machine.resize(len);
+	QString sMachine = QString("%1").arg(machine.data()).trimmed();
+	if (!sMachine.isEmpty())
+		log(QString("Machine: %1").arg(sMachine));
 #endif
 
 #ifdef Q_OS_SOLARIS
 	processor_info_t pinfo;
 	processor_info(0, &pinfo);
-	//log(QString("Processor name: %1").arg(pinfo.pi_processor_type));
-	log(QString("Processor speed: %1 MHz").arg(pinfo.pi_clock));
+	//log(QString("CPU name: %1").arg(pinfo.pi_processor_type));
+	log(QString("CPU speed: %1 MHz").arg(pinfo.pi_clock));
 
 	int ncpu = sysconf( _SC_NPROCESSORS_ONLN );
-	log(QString("Processor logical cores: %1").arg(ncpu));
+	log(QString("CPU logical cores: %1").arg(ncpu));
 
 	// memory info
 	uint64_t totalRAM = (size_t)sysconf( _SC_PHYS_PAGES ) * (size_t)sysconf( _SC_PAGESIZE );
@@ -402,13 +506,13 @@ void printSystemInfo()
 	else
 		clockSpeed = QString("%1 GHz").arg(QString::number(frequency/1000.f, 'f', 2));
 
-	log(QString("Processor name: %1 %2 @ %3").arg(get_cpu_vendor_string(cpuVendor), get_cpu_model_string(platform, cpuVendor, cpuModel), clockSpeed));
-	log(QString("Processor speed: %1 MHz").arg(frequency));
+        log(QString("CPU name: %1 %2 @ %3").arg(get_cpu_vendor_string(cpuVendor), get_cpu_model_string(platform, cpuVendor, cpuModel), clockSpeed));
+        log(QString("CPU speed: %1 MHz").arg(frequency));
 
 	system_info hwinfo;
 	get_system_info(&hwinfo);
 
-	log(QString("Processor logical cores: %1").arg(hwinfo.cpu_count));
+        log(QString("CPU logical cores: %1").arg(hwinfo.cpu_count));
 
 	// memory info
 	uint64_t totalRAM = round(hwinfo.max_pages*B_PAGE_SIZE/1048576.0 + hwinfo.ignored_pages*B_PAGE_SIZE/1048576.0);
