@@ -56,6 +56,7 @@
 #include "StelSkyLayerMgr.hpp"
 #include "StelAudioMgr.hpp"
 #include "StelVideoMgr.hpp"
+#include "StelSpeechMgr.hpp"
 #include "SpecialMarkersMgr.hpp"
 #include "StelViewportEffect.hpp"
 #include "StelGuiBase.hpp"
@@ -100,6 +101,7 @@
 #include <QDateTime>
 #include <QRegularExpression>
 #include <QRandomGenerator>
+#include <QFontDatabase>
 #if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 #include <QImageReader>
 #endif
@@ -200,6 +202,10 @@ Q_IMPORT_PLUGIN(ObservabilityStelPluginInterface)
 Q_IMPORT_PLUGIN(Scenery3dStelPluginInterface)
 #endif
 
+#ifdef USE_STATIC_PLUGIN_SKYCULTUREMAKER
+Q_IMPORT_PLUGIN(SkyCultureMakerStelPluginInterface)
+#endif
+
 #ifdef USE_STATIC_PLUGIN_REMOTECONTROL
 Q_IMPORT_PLUGIN(RemoteControlStelPluginInterface)
 #endif
@@ -225,7 +231,7 @@ Q_IMPORT_PLUGIN(MosaicCameraStelPluginInterface)
 #endif
 
 // Initialize static variables
-StelApp* StelApp::singleton = Q_NULLPTR;
+StelApp* StelApp::singleton = nullptr;
 qint64 StelApp::startMSecs = 0;
 double StelApp::animationScale = 1.;
 
@@ -244,32 +250,33 @@ void StelApp::deinitStatic()
 *************************************************************************/
 StelApp::StelApp(StelMainView *parent)
 	: QObject(parent)
-	, randomGenerator(Q_NULLPTR)
+	, randomGenerator(nullptr)
 	, mainWin(parent)
-	, core(Q_NULLPTR)
-	, moduleMgr(Q_NULLPTR)
-	, localeMgr(Q_NULLPTR)
-	, skyCultureMgr(Q_NULLPTR)
-	, actionMgr(Q_NULLPTR)
-	, propMgr(Q_NULLPTR)
-	, textureMgr(Q_NULLPTR)
-	, stelObjectMgr(Q_NULLPTR)
-	, planetLocationMgr(Q_NULLPTR)
-	, networkAccessManager(Q_NULLPTR)
-	, audioMgr(Q_NULLPTR)
-	, videoMgr(Q_NULLPTR)
-	, skyImageMgr(Q_NULLPTR)
+	, core(nullptr)
+	, moduleMgr(nullptr)
+	, localeMgr(nullptr)
+	, skyCultureMgr(nullptr)
+	, actionMgr(nullptr)
+	, propMgr(nullptr)
+	, textureMgr(nullptr)
+	, stelObjectMgr(nullptr)
+	, planetLocationMgr(nullptr)
+	, networkAccessManager(nullptr)
+	, audioMgr(nullptr)
+	, videoMgr(nullptr)
+	, speechMgr(nullptr)
+	, skyImageMgr(nullptr)
 #ifdef ENABLE_SCRIPTING
-	, scriptAPIProxy(Q_NULLPTR)
-	, scriptMgr(Q_NULLPTR)
+	, scriptAPIProxy(nullptr)
+	, scriptMgr(nullptr)
 #endif
-	, stelGui(Q_NULLPTR)
+	, stelGui(nullptr)
 	, devicePixelsPerPixel(1.)
 	, fps(0)
 	, frame(0)
 	, frameTimeAccum(0.)
 	, flagNightVision(false)
-	, confSettings(Q_NULLPTR)
+	, confSettings(nullptr)
 	, initialized(false)
 	, saveProjW(-1.)
 	, saveProjH(-1.)
@@ -278,18 +285,19 @@ StelApp::StelApp(StelMainView *parent)
 	, nbUsedCache(0)
 	, totalUsedCacheSize(0)
 	, screenFontSize(getDefaultGuiFontSize())
-	, renderBuffer(Q_NULLPTR)
-	, viewportEffect(Q_NULLPTR)
-	, gl(Q_NULLPTR)
+	, renderBuffer(nullptr)
+	, viewportEffect(nullptr)
+	, gl(nullptr)
 	, flagShowDecimalDegrees(false)
 	, flagUseAzimuthFromSouth(false)
+	, flagUseNegativeHourAngles(false)
 	, flagUseFormattingOutput(false)
 	, flagUseCCSDesignation(false)
 	, flagOverwriteInfoColor(false)
 	, overwriteInfoColor(Vec3f(1.f))
 	, daylightInfoColor(Vec3f(0.f))
 	#ifdef ENABLE_SPOUT
-	, spoutSender(Q_NULLPTR)
+	, spoutSender(nullptr)
 	#endif
 	, currentFbo(0)
 {
@@ -321,22 +329,23 @@ StelApp::~StelApp()
 	moduleMgr->unloadModule("StelSkyCultureMgr", true);// No need to delete only later!
 	StelModuleMgr* tmp = moduleMgr;
 	moduleMgr = new StelModuleMgr(); // Create a secondary instance to avoid crashes at other deinit
-	delete tmp; tmp=Q_NULLPTR;
-	delete skyImageMgr; skyImageMgr=Q_NULLPTR;
-	delete core; core=Q_NULLPTR;
-	delete localeMgr; localeMgr=Q_NULLPTR;
-	delete audioMgr; audioMgr=Q_NULLPTR;
-	delete videoMgr; videoMgr=Q_NULLPTR;
-	delete stelObjectMgr; stelObjectMgr=Q_NULLPTR; // Delete the module by hand afterward
-	delete textureMgr; textureMgr=Q_NULLPTR;
-	delete planetLocationMgr; planetLocationMgr=Q_NULLPTR;
-	delete moduleMgr; moduleMgr=Q_NULLPTR; // Delete the secondary instance
-	delete actionMgr; actionMgr = Q_NULLPTR;
-	delete propMgr; propMgr = Q_NULLPTR;
-	delete renderBuffer; renderBuffer = Q_NULLPTR;
-	delete randomGenerator; randomGenerator=Q_NULLPTR;
+	delete tmp; tmp=nullptr;
+	delete skyImageMgr; skyImageMgr=nullptr;
+	delete core; core=nullptr;
+	delete localeMgr; localeMgr=nullptr;
+	delete audioMgr; audioMgr=nullptr;
+	delete videoMgr; videoMgr=nullptr;
+	//delete speechMgr; speechMgr=nullptr;
+	delete stelObjectMgr; stelObjectMgr=nullptr; // Delete the module by hand afterward
+	delete textureMgr; textureMgr=nullptr;
+	delete planetLocationMgr; planetLocationMgr=nullptr;
+	delete moduleMgr; moduleMgr=nullptr; // Delete the secondary instance
+	delete actionMgr; actionMgr = nullptr;
+	delete propMgr; propMgr = nullptr;
+	delete renderBuffer; renderBuffer = nullptr;
+	delete randomGenerator; randomGenerator=nullptr;
 	Q_ASSERT(singleton);
-	singleton = Q_NULLPTR;
+	singleton = nullptr;
 }
 
 void StelApp::setupNetworkProxy()
@@ -499,7 +508,6 @@ void StelApp::init(QSettings* conf)
 	//create non-StelModule managers
 	propMgr = new StelPropertyMgr();
 	skyCultureMgr = new StelSkyCultureMgr();
-	skyCultureMgr->init();
 	getModuleMgr().registerModule(skyCultureMgr);
 
 	planetLocationMgr = new StelLocationMgr();
@@ -595,6 +603,14 @@ void StelApp::init(QSettings* conf)
 	videoMgr->init();
 	getModuleMgr().registerModule(videoMgr);
 
+	// Init speech manager. If no media or Qt too low, this installs a dummy object, the initialisation of which need not be announced.
+#if defined(ENABLE_MEDIA) && (QT_VERSION>=QT_VERSION_CHECK(6,6,0))
+	SplashScreen::showMessage(q_("Initializing speech output..."));
+#endif
+	speechMgr = new StelSpeechMgr();
+	speechMgr->init();
+	getModuleMgr().registerModule(speechMgr);
+
 	// Constellations
 	SplashScreen::showMessage(q_("Initializing constellations..."));
 	ConstellationMgr* constellations = new ConstellationMgr(hip_stars);
@@ -694,6 +710,8 @@ void StelApp::init(QSettings* conf)
 
 	setFlagShowDecimalDegrees(confSettings->value("gui/flag_show_decimal_degrees", false).toBool());
 	setFlagSouthAzimuthUsage(confSettings->value("gui/flag_use_azimuth_from_south", false).toBool());
+	setFlagUseNegativeHourAngles(confSettings->value("gui/flag_use_negative_hour_angles", false).toBool());
+	setFlagPolarDistanceUsage(confSettings->value("gui/flag_use_polar_distance", false).toBool());
 	setFlagUseFormattingOutput(confSettings->value("gui/flag_use_formatting_output", false).toBool());
 	setFlagUseCCSDesignation(confSettings->value("gui/flag_use_ccs_designations", false).toBool());
 	setFlagOverwriteInfoColor(confSettings->value("gui/flag_overwrite_info_color", false).toBool());	
@@ -732,7 +750,7 @@ void StelApp::init(QSettings* conf)
 			{
 				QMessageBox::warning(&StelMainView::getInstance(), "Stellarium SPOUT", q_("Cannot create Spout sender. See log for details."), QMessageBox::Ok);
 				delete spoutSender;
-				spoutSender = Q_NULLPTR;
+				spoutSender = nullptr;
 				qApp->setProperty("spout", "");
 			}
 			SplashScreen::clearMessage();
@@ -759,7 +777,7 @@ void StelApp::initPlugIns()
 			continue;
 		SplashScreen::showMessage(QString("%1 \"%2\"...").arg(q_("Loading plugin"), q_(i.info.displayedName)));
 		StelModule* m = moduleMgr->loadPlugin(i.info.id);
-		if (m!=Q_NULLPTR)
+		if (m!=nullptr)
 		{
 			moduleMgr->registerModule(m, true);
 			//load extensions after the module is registered
@@ -774,7 +792,7 @@ void StelApp::deinit()
 {
 #ifdef 	ENABLE_SPOUT
 	delete spoutSender;
-	spoutSender = Q_NULLPTR;
+	spoutSender = nullptr;
 #endif
 #ifdef ENABLE_SCRIPTING
 	if (scriptMgr->scriptIsRunning())
@@ -1278,6 +1296,26 @@ void StelApp::setFlagSouthAzimuthUsage(bool use)
 	}
 }
 
+void StelApp::setFlagUseNegativeHourAngles(bool use)
+{
+	if (flagUseNegativeHourAngles!=use)
+	{
+		flagUseNegativeHourAngles=use;
+		StelApp::immediateSave("gui/flag_use_negative_hour_angles", use);
+		emit flagUseNegativeHourAnglesChanged(use);
+	}
+}
+
+void StelApp::setFlagPolarDistanceUsage(bool use)
+{
+	if (flagUsePolarDistance!=use)
+	{
+		flagUsePolarDistance=use;
+		StelApp::immediateSave("gui/flag_use_polar_distance", use);
+		emit flagUsePolarDistanceChanged(use);
+	}
+}
+
 
 void StelApp::setFlagUseFormattingOutput(bool b)
 {
@@ -1396,13 +1434,17 @@ void StelApp::quit()
 void StelApp::setDevicePixelsPerPixel(qreal dppp)
 {
 	// Check that the device-independent pixel size didn't change
-	if (!viewportEffect && !fuzzyEquals(devicePixelsPerPixel, dppp))
+	if (!fuzzyEquals(devicePixelsPerPixel, dppp))
 	{
 		qDebug() << "Changing high-DPI scaling factor from" << devicePixelsPerPixel << "to" << dppp;
+		const auto effect = getViewportEffect();
+		setViewportEffect("none");
 		devicePixelsPerPixel = dppp;
 		StelProjector::StelProjectorParams params = core->getCurrentStelProjectorParams();
 		params.devicePixelsPerPixel = devicePixelsPerPixel;
 		core->setCurrentStelProjectorParams(params);
+		// Force to recreate the viewport effect if any.
+		setViewportEffect(effect);
 	}
 }
 
@@ -1414,12 +1456,12 @@ void StelApp::setViewportEffect(const QString& name)
 	{
 		ensureGLContextCurrent();
 		delete renderBuffer;
-		renderBuffer = Q_NULLPTR;
+		renderBuffer = nullptr;
 	}
 	if (viewportEffect)
 	{
 		delete viewportEffect;
-		viewportEffect = Q_NULLPTR;
+		viewportEffect = nullptr;
 	}
 	if (name == "none") return;
 
@@ -1538,3 +1580,17 @@ void StelApp::enableBottomStelBarUpdates(bool enable)
 	StelGui *gui=dynamic_cast<StelGui*>(getGui());
 	gui->getButtonBar()->enableTopoCentricUpdate(enable);
 }
+
+void StelApp::dumpFontInfo() const
+{
+#if (QT_VERSION<QT_VERSION_CHECK(6,0,0))
+	qInfo() << "StelApp::dumpFontInfo() not available for Qt5 builds.";
+#else
+	const QList<QFontDatabase::WritingSystem> writingSystems=QFontDatabase::writingSystems();
+	qInfo() << "WritingSystems and Font Families:";
+	for (const auto &ws: writingSystems)
+	{
+		qInfo() << ws << ":" << QFontDatabase::families(ws);
+	}
+#endif
+}
