@@ -153,6 +153,14 @@ class StelSkyCultureMgr : public StelModule
 		   READ getInfoLabelStyle
 		   WRITE setInfoLabelStyle
 		   NOTIFY infoLabelStyleChanged)
+	Q_PROPERTY(StelObject::CulturalDisplayStyle zodiacLabelStyle
+		   READ getZodiacLabelStyle
+		   WRITE setZodiacLabelStyle
+		   NOTIFY zodiacLabelStyleChanged)
+	Q_PROPERTY(StelObject::CulturalDisplayStyle lunarSystemLabelStyle
+		   READ getLunarSystemLabelStyle
+		   WRITE setLunarSystemLabelStyle
+		   NOTIFY lunarSystemLabelStyleChanged)
 	Q_PROPERTY(bool flagUseAbbreviatedNames
 		   READ getFlagUseAbbreviatedNames
 		   WRITE setFlagUseAbbreviatedNames
@@ -219,7 +227,13 @@ public slots:
 	//! Returns a localized HTML description for the current sky culture.
 	//! @return a HTML description of the current sky culture, suitable for display
 	QString getCurrentSkyCultureHtmlDescription();
-	
+	//! Returns a localized narration text for the current sky culture.
+	//! @return a plaintext description of the current sky culture, suitable for narration
+	//! This only includes the text before section "## Constellations".
+	//! The Constellation texts are narrated one-by-one when selected,
+	//! and references/authors/license are likely nothing of so great interest.
+	QString getCurrentSkyCultureNarration();
+
 	//! Get the default sky culture ID
 	QString getDefaultSkyCultureID() {return defaultSkyCultureID;}
 	//! Set the default sky culture from the ID.
@@ -262,6 +276,24 @@ public slots:
 	//! scripting version
 	void setInfoLabelStyle(const QString &style);
 
+	//! Returns the Zodiac labeling setting for the currently active skyculture
+	StelObject::CulturalDisplayStyle getZodiacLabelStyle() const;
+	//! Scripting version
+	QString getZodiacLabelStyleString() const;
+	//! sets the Zodiac labeling setting for the currently active skyculture
+	void setZodiacLabelStyle(const StelObject::CulturalDisplayStyle style);
+	//! scripting version
+	void setZodiacLabelStyle(const QString &style);
+
+	//! Returns the Lunar_System labeling setting for the currently active skyculture
+	StelObject::CulturalDisplayStyle getLunarSystemLabelStyle() const;
+	//! Scripting version
+	QString getLunarSystemLabelStyleString() const;
+	//! sets the Lunar_System labeling setting for the currently active skyculture
+	void setLunarSystemLabelStyle(const StelObject::CulturalDisplayStyle style);
+	//! scripting version
+	void setLunarSystemLabelStyle(const QString &style);
+
 	//! Returns whether we ignore SC authors' settings "fallback_to_international_names"
 	bool getFlagOverrideUseCommonNames() const {return flagOverrideUseCommonNames; }
 	//! Set whether we ignore SC authors' settings "fallback_to_international_names"
@@ -275,6 +307,8 @@ public slots:
 	//! Returns whether current skyculture uses (incorporates) common names.
 	bool currentSkycultureUsesCommonNames() const;
 
+	//! Debugging/developing function. Call via scripting.
+	void analyzeScreenLabel() const;
 signals:
 	//! Emitted whenever the default sky culture changed.
 	//! @see setDefaultSkyCultureID
@@ -290,6 +324,10 @@ signals:
 	void infoLabelStyleChanged(const StelObject::CulturalDisplayStyle style);
 	//! Emitted when ScreenLabelStyle has changed
 	void screenLabelStyleChanged(const StelObject::CulturalDisplayStyle style);
+	//! Emitted when ZodiacLabelStyle has changed
+	void zodiacLabelStyleChanged(const StelObject::CulturalDisplayStyle style);
+	//! Emitted when Lunar_System LabelStyle has changed
+	void lunarSystemLabelStyleChanged(const StelObject::CulturalDisplayStyle style);
 
 	//! Emitted on flag change.
 	void flagOverrideUseCommonNamesChanged(bool override);
@@ -321,8 +359,13 @@ private:
 	QString skyCultureI18ToDirectory(const QString& cultureName) const;
 
 	QString descriptionMarkdownToHTML(const QString& markdown, const QString& descrPath);
+	QString descriptionMarkdownToNarration(const QString& markdown, const QString& descrPath);
+	// We don't use QHash/QMap because we want to preserve order of constellations as listed in the description file
+	std::vector<std::pair<QString/*constellation*/, QString/*description*/>> getConstellationsDescriptions(QString consSection) const;
 	QString convertMarkdownLevel2Section(const QString& markdown, const QString& sectionName,
 	                                     qsizetype bodyStartPos, qsizetype bodyEndPos, const StelTranslator& trans);
+	QString convertMarkdownLevel2SectionNarration(const QString& markdown, const QString& sectionName,
+					     qsizetype bodyStartPos, qsizetype bodyEndPos, const StelTranslator& trans);
 	std::pair<QString/*color*/,QString/*info*/> getLicenseDescription(const QString& license, const bool singleLicenseForAll) const;
 
 	QMap<QString, StelSkyCulture> dirToNameEnglish;
@@ -337,6 +380,15 @@ private:
 	//! Replace any detailed cultural label by the short label (from constellation ID)
 	//! This should be a short string, some skycultures still have numerical IDs here.
 	bool flagUseAbbreviatedNames;
+
+public:
+	//! Convert input in Markdown style to formatted HTML
+	static QString markdownToHTML(QString input);
+private:
+	//! Restyle a few style annotations
+	static void applyStyleToMarkdown(QString& string);
+	//! convert numerical citations from [#n] style to HTML superscript style
+	static QString convertReferenceLinks(QString text);
 };
 
 #endif // STELSKYCULTUREMGR_HPP
