@@ -20,6 +20,8 @@
 
 #include <QJsonObject>
 #include <QJsonArray>
+#include <QFont>
+#include <QFontMetrics>
 
 #include "StarMgr.hpp"
 #include "StelLocaleMgr.hpp"
@@ -32,7 +34,7 @@
 StelSkyCultureSkyPartition::StelSkyCultureSkyPartition(const QJsonObject &json):
 	frameType(StelCore::FrameObservercentricEclipticOfDate),
 	partitions(),
-	extent(90.),
+	extent(QList<double>{90.}),
 	centerLine(nullptr),
 	linkStars(),
 	offset(0.0),
@@ -60,10 +62,18 @@ StelSkyCultureSkyPartition::StelSkyCultureSkyPartition(const QJsonObject &json):
 	if (json.contains("context"))
 		context = json["context"].toString();
 
-	// Parse extent, create polar caps where needed.
+	// Parse extent: either one value defining north/south caps, or per-station limits.
 	if (json.contains("extent") && json["extent"].isDouble())
 	{
-		extent=json["extent"].toDouble();
+		extent.clear();
+		extent.append(json["extent"].toDouble());
+	}
+	else if (json.contains("extent") && json["extent"].isArray())
+	{
+		extent.clear();
+		QJsonArray ext=json["extent"].toArray();
+		for (unsigned int i=0; i<ext.size(); ++i)
+			extent.append(ext.at(i).toDouble());
 	}
 	else
 		qWarning() << "Bad \"extent\" given in JSON file.";
@@ -161,7 +171,7 @@ StelSkyCultureSkyPartition::StelSkyCultureSkyPartition(const QJsonObject &json):
 	}
 
 	// Font size is 14
-	font.setPixelSize(StelApp::getInstance().getScreenFontSize()+1);
+	fontSize = StelApp::getInstance().getScreenFontSize()+1;
 	updateLabels();
 
 	// Recapitulate what we have loaded:
@@ -174,19 +184,29 @@ StelSkyCultureSkyPartition::~StelSkyCultureSkyPartition()
 //	if (centerLine) delete centerLine;
 }
 
+void StelSkyCultureSkyPartition::update(double deltaTime)
+{
+	static StelCore *core=StelApp::getInstance().getCore();
+	static SolarSystem *solSys=GETSTELMODULE(SolarSystem);
+	eclObl = solSys->getEarth()->getRotObliquity(core->getJDE());
+	centerLine->update(deltaTime);
+}
+
 
 void StelSkyCultureSkyPartition::draw(StelPainter& sPainter, const Vec3d &obsVelocity)
 {
 	static StelSkyCultureMgr *scMgr=GETSTELMODULE(StelSkyCultureMgr);
 	static StarMgr *starMgr=GETSTELMODULE(StarMgr);
 	static StelCore *core=StelApp::getInstance().getCore();
-	eclObl = GETSTELMODULE(SolarSystem)->getEarth()->getRotObliquity(core->getJDE());
 	StelProjectorP prj = core->getProjection(frameType, (frameType!=StelCore::FrameAltAz && frameType!=StelCore::FrameFixedEquatorial) ? StelCore::RefractionAuto : StelCore::RefractionOff);
 	sPainter.setProjector(prj);
+	QFont font=QGuiApplication::font();
+	font.setPixelSize(fontSize);
 	const bool lrFlipped=core->getFlipHorz();
 	const bool vertFlipped=core->getFlipVert();
 	const double txtOffset=lrFlipped ? 0.1 : -0.1; // coordinate offset for projecting text
-	const float yShift = vertFlipped ? -font.pixelSize() : 0.f;
+	const float yShift = vertFlipped ? -fontSize : 0.f;
+	const float screenScale = prj->getDevicePixelsPerPixel();
 
 	// If defined, find the necessary shift from single linkStar and offset
 	if (linkStars.length()==1)
@@ -209,7 +229,7 @@ void StelSkyCultureSkyPartition::draw(StelPainter& sPainter, const Vec3d &obsVel
 
 	if (linkStars.length()>1)
 	{
-		// Chinese systems: Unequal partitions defined by stars.
+		// Chinese systems: Unequal partitions defined by stars. We can also safely assume extent has only one value.
 		foreach(const int starId, linkStars)
 		{
 			//qDebug() << "drawing line for HIP"  << starId;
@@ -220,8 +240,8 @@ void StelSkyCultureSkyPartition::draw(StelPainter& sPainter, const Vec3d &obsVel
 			StelUtils::rectToSphe(&ra, &dec, posDate);
 			Vec3d eqPt, nPt, sPt;
 			StelUtils::spheToRect(ra, 0., eqPt);
-			StelUtils::spheToRect(ra, extent*M_PI_180, nPt);
-			StelUtils::spheToRect(ra, -extent*M_PI_180, sPt);
+			StelUtils::spheToRect(ra, extent.at(0)*M_PI_180, nPt);
+			StelUtils::spheToRect(ra, -extent.at(0)*M_PI_180, sPt);
 			sPainter.drawGreatCircleArc(eqPt, nPt);
 			sPainter.drawGreatCircleArc(eqPt, sPt);
 			//qDebug() << "done line for HIP"  << starId;
@@ -239,20 +259,44 @@ void StelSkyCultureSkyPartition::draw(StelPainter& sPainter, const Vec3d &obsVel
 			const double lng=(360./partitions[0]*p +offsetFromAries)*M_PI_180;
 			Vec3d eqPt, nPt, sPt;
 			StelUtils::spheToRect(lng, 0., eqPt);
-			StelUtils::spheToRect(lng, extent*M_PI_180, nPt);
-			StelUtils::spheToRect(lng, -extent*M_PI_180, sPt);
+			double nExt, sExt;
+			if (extent.length()==1)
+			{
+				nExt=extent.at(0);
+				sExt=-extent.at(0);
+			}
+			else
+			{
+				Q_ASSERT(extent.length() == 2*partitions.length());
+				nExt=qMax(extent.at(2*p),   extent.at(2*((p-1+partitions[0]) % partitions[0])));
+				sExt=qMin(extent.at(2*p+1), extent.at(2*((p-1+partitions[0]) % partitions[0])+1));
+			}
+			StelUtils::spheToRect(lng, nExt*M_PI_180, nPt);
+			StelUtils::spheToRect(lng, sExt*M_PI_180, sPt);
 			sPainter.drawGreatCircleArc(eqPt, nPt);
 			sPainter.drawGreatCircleArc(eqPt, sPt);
 		}
 	}
 
 	// Draw top/bottom lines where applicable
-	if (extent<90.)
+	if ((extent.length()==1) && (extent.at(0)<90.))
 	{
 		// Get the bounding halfspace
 		const SphericalCap& viewPortSphericalCap = sPainter.getProjector()->getBoundingCap();
-		drawCap(sPainter, viewPortSphericalCap, extent);
-		drawCap(sPainter, viewPortSphericalCap, -extent);
+		drawCap(sPainter, viewPortSphericalCap, extent.at(0));
+		drawCap(sPainter, viewPortSphericalCap, -extent.at(0));
+	}
+	else if (extent.length()>1)
+	{
+		// TODO: Arab LM may show sectioned boxes.
+		for (int p=0; p<partitions[0]; ++p)
+		{
+			// Get the bounding halfspace
+			const SphericalCap& viewPortSphericalCap = sPainter.getProjector()->getBoundingCap();
+			// TODO: draw 2 small arcs per LM in the given extent latitudes
+			drawMansionCap(sPainter, viewPortSphericalCap, extent.at(2*p), p*360.0/partitions[0]+offsetFromAries, (p+1)*360.0/partitions[0]+offsetFromAries);
+			drawMansionCap(sPainter, viewPortSphericalCap, extent.at(2*p+1), p*360.0/partitions[0]+offsetFromAries, (p+1)*360.0/partitions[0]+offsetFromAries);
+		}
 	}
 
 	centerLine->setCulturalOffset(offsetFromAries);
@@ -263,17 +307,21 @@ void StelSkyCultureSkyPartition::draw(StelPainter& sPainter, const Vec3d &obsVel
 	{
 		for (int i=0; i<partitions[0]; ++i)
 		{
+			const QString symbol=symbols.at(i).trimmed();
 			// To have tilted labels, we project a point 0.1deg from the actual label point and derive screen-based angle.
-			double lng  = (360./partitions[0]*i + 2.+offsetFromAries)*M_PI_180;
-			double lng1 = (360./partitions[0]*i + 2.+offsetFromAries + txtOffset)*M_PI_180;
-			double lat  = (extent<50. ? -extent+0.2 : -10.) *M_PI_180;
+			double lng  = (360./partitions[0]*i + offsetFromAries)*M_PI_180;
+			double lng1 = (360./partitions[0]*i + offsetFromAries + txtOffset)*M_PI_180;
+			// the displayed latitude is defined in the first LM.
+			double lat = (extent.at(0)<50. ? -extent.at(0)+0.2 : -10.) *M_PI_180;
 			Vec3d pos, pos1, scr, scr1;
 			StelUtils::spheToRect(lng, lat, pos);
 			StelUtils::spheToRect(lng1, lat, pos1);
 			prj->project(pos, scr);
 			prj->project(pos1, scr1);
 			double angle=atan2(scr1[1]-scr[1], scr1[0]-scr[0])*M_180_PI;
-			sPainter.drawText(pos, symbols.at(i), angle, 0.f, yShift);
+			QFontMetrics metrics(font);
+			float xShift= -1.5 * metrics.boundingRect(symbol).width();
+			sPainter.drawText(pos, symbol, angle, xShift*screenScale, yShift*screenScale);
 		}
 	}
 	else if (symbols.length()==linkStars.length()  && linkStars.length()>1)
@@ -281,16 +329,16 @@ void StelSkyCultureSkyPartition::draw(StelPainter& sPainter, const Vec3d &obsVel
 		// Chinese Symbols
 		for (int i=0; i<linkStars.length(); ++i)
 		{
-			QString label=symbols.at(i);
+			const QString symbol=symbols.at(i).trimmed();
 			StelObjectP starBegin = starMgr->searchHP(linkStars.at(i));
 
 			Vec3d eq=starBegin->getEquinoxEquatorialPos(core);
 			double ra, dec;
 			StelUtils::rectToSphe(&ra, &dec, eq);
 
-			ra += 2.*M_PI_180; // push a bit into the mansion area. Problem: the narrow mansions...
+			//ra += 2.*M_PI_180; // push a bit into the mansion area. Problem: the narrow mansions...
 			double ra1 = ra+txtOffset*M_PI_180;
-			double dec1  = (extent<50. ? -extent+0.2 : -10.) *M_PI_180;
+			double dec1  = (extent.at(0)<50. ? -extent.at(0)+0.2 : -10.) *M_PI_180;
 			Vec3d pos, pos1, scr, scr1;
 			StelUtils::spheToRect(ra, dec1, pos);
 			StelUtils::spheToRect(ra1, dec1, pos1);
@@ -298,9 +346,9 @@ void StelSkyCultureSkyPartition::draw(StelPainter& sPainter, const Vec3d &obsVel
 			prj->project(pos1, scr1);
 			float angle=atan2(scr1[1]-scr[1], scr1[0]-scr[0])*M_180_PIf;
 			QFontMetrics metrics(font);
-			float xShift= -0.5 * metrics.boundingRect(label).width();
+			float xShift= -1.5 * metrics.boundingRect(symbol).width();
 
-			sPainter.drawText(pos, label, angle, xShift, yShift);
+			sPainter.drawText(pos, symbol, angle, xShift*screenScale, yShift*screenScale);
 		}
 	}
 
@@ -309,28 +357,28 @@ void StelSkyCultureSkyPartition::draw(StelPainter& sPainter, const Vec3d &obsVel
 	{
 		for (int i=0; i<partitions[0]; ++i)
 		{
-			QString label=scMgr->createCulturalLabel(names.at(i), scMgr->getScreenLabelStyle(), names.at(i).pronounceI18n);
+			const QString label=scMgr->createCulturalLabel(names.at(i), partitions[0]==12 ? scMgr->getZodiacLabelStyle() : scMgr->getLunarSystemLabelStyle(), QString()).trimmed();
 			// To have tilted labels, we project a point 0.1deg from the actual label point and derive screen-based angle.
-			double lng  = (360./partitions[0]*(double(i)+0.5) + 2.+offsetFromAries)*M_PI_180;
-			double lng1 = (360./partitions[0]*(double(i)+0.5) + 2.+offsetFromAries+txtOffset)*M_PI_180;
-			double lat  = (extent<50. ? -extent+0.2 : -10.) *M_PI_180;
+			const double lng  = (360./partitions[0]*(double(i)+0.5) + offsetFromAries)*M_PI_180;
+			const double lng1 = (360./partitions[0]*(double(i)+0.5) + offsetFromAries+txtOffset)*M_PI_180;
+			const double lat  = (extent.at(0)<50. ? -extent.at(0)+0.2 : -10.) *M_PI_180;
 			Vec3d pos, pos1, scr, scr1;
 			StelUtils::spheToRect(lng, lat, pos);
 			StelUtils::spheToRect(lng1, lat, pos1);
 			prj->project(pos, scr);
 			prj->project(pos1, scr1);
-			float angle=atan2(scr1[1]-scr[1], scr1[0]-scr[0])*M_180_PIf;
+			const float angle=atan2(scr1[1]-scr[1], scr1[0]-scr[0])*M_180_PIf;
 			QFontMetrics metrics(font);
 			float xShift= -0.5 * metrics.boundingRect(label).width();
 
-			sPainter.drawText(pos, label, angle, xShift, yShift);
+			sPainter.drawText(pos, label, angle, xShift*screenScale, yShift*screenScale);
 		}
 	}
 	else if (names.length()==linkStars.length()  && linkStars.length()>1)
 	{
 		for (int i=0; i<linkStars.length(); ++i)
 		{
-			QString label=scMgr->createCulturalLabel(names.at(i), scMgr->getScreenLabelStyle(),names.at(i).pronounceI18n);
+			QString label=scMgr->createCulturalLabel(names.at(i), scMgr->getLunarSystemLabelStyle(),names.at(i).pronounceI18n).trimmed();
 			StelObjectP starBegin = starMgr->searchHP(linkStars.at(i));
 			StelObjectP starEnd   = starMgr->searchHP(linkStars.at((i==linkStars.length()-1? 0 : i+1)));
 
@@ -338,18 +386,18 @@ void StelSkyCultureSkyPartition::draw(StelPainter& sPainter, const Vec3d &obsVel
 			double ra, dec;
 			StelUtils::rectToSphe(&ra, &dec, mid);
 
-			double ra1 = ra+txtOffset*M_PI_180;
-			double dec1  = (extent<50. ? -extent+0.2 : -10.) *M_PI_180;
+			const double ra1 = ra+txtOffset*M_PI_180;
+			const double dec1  = (extent.at(0)<50. ? -extent.at(0)+0.2 : -10.) *M_PI_180;
 			Vec3d pos, pos1, scr, scr1;
 			StelUtils::spheToRect(ra, dec1, pos);
 			StelUtils::spheToRect(ra1, dec1, pos1);
 			prj->project(pos, scr);
 			prj->project(pos1, scr1);
-			float angle=atan2(scr1[1]-scr[1], scr1[0]-scr[0])*M_180_PIf;
+			const float angle=atan2(scr1[1]-scr[1], scr1[0]-scr[0])*M_180_PIf;
 			QFontMetrics metrics(font);
 			float xShift= -0.5 * metrics.boundingRect(label).width();
 
-			sPainter.drawText(pos, label, angle, xShift, yShift);
+			sPainter.drawText(pos, label, angle, xShift*screenScale, yShift*screenScale);
 		}
 	}
 }
@@ -357,7 +405,7 @@ void StelSkyCultureSkyPartition::draw(StelPainter& sPainter, const Vec3d &obsVel
 // shamelessly copied from SkyLine::draw (small circles part)
 void StelSkyCultureSkyPartition::drawCap(StelPainter &sPainter, const SphericalCap& viewPortSphericalCap, double latDeg) const
 {
-	double lat=latDeg*M_PI_180;
+	const double lat=latDeg*M_PI_180;
 	SphericalCap declinationCap(Vec3d(0.,0.,1.), std::sin(lat));
 	const Vec3d rotCenter(0,0,declinationCap.d);
 
@@ -400,9 +448,21 @@ void StelSkyCultureSkyPartition::drawCap(StelPainter &sPainter, const SphericalC
 	}
 }
 
+void StelSkyCultureSkyPartition::drawMansionCap(StelPainter &sPainter, const SphericalCap& viewPortSphericalCap, double latDeg, double lon1, double lon2) const
+{
+	const double lat=latDeg*M_PI_180;
+	SphericalCap declinationCap(Vec3d(0.,0.,1.), std::sin(lat));
+	const Vec3d rotCenter(0,0,declinationCap.d);
+	Vec3d pt1, pt2;
+	StelUtils::spheToRect(lon1*M_PI_180, lat, pt1); //pt1.normalize();
+	StelUtils::spheToRect(lon2*M_PI_180, lat, pt2); //pt2.normalize();
+	sPainter.drawSmallCircleArc(pt1, pt2, rotCenter, nullptr, nullptr);
+}
+
+
 void StelSkyCultureSkyPartition::setFontSize(int newFontSize)
 {
-	font.setPixelSize(newFontSize);
+	fontSize = newFontSize;
 }
 
 void StelSkyCultureSkyPartition::updateLabels()
@@ -457,12 +517,18 @@ void StelSkyCultureSkyPartition::updateI18n()
 QString StelSkyCultureSkyPartition::getCulturalName() const
 {
 	static StelSkyCultureMgr *scMgr=GETSTELMODULE(StelSkyCultureMgr);
-	return scMgr->createCulturalLabel(name, scMgr->getScreenLabelStyle(), name.pronounceI18n);
+	return scMgr->createCulturalLabel(name, StelObject::CulturalDisplayStyle::Pronounce, names.length()==12 ? q_("Zodiac") : q_("Lunar Station"));
 }
 
-QString StelSkyCultureSkyPartition::getLongitudeCoordinate(Vec3d &eqPos) const
+QString StelSkyCultureSkyPartition::getLongitudeCoordinate(Vec3d &eqPos, bool narration) const
 {
 	static StelSkyCultureMgr *scMgr=GETSTELMODULE(StelSkyCultureMgr);
+	const QString sDegrees=qc_("degrees", "object narration");
+	const QString sMinutes=qc_("minutes", "object narration");
+	const QString sAnd=qc_("and", "object narration");
+	const QString sSeconds=qc_("seconds", "object narration");
+	const QString sPada=qc_("pada", "object narration; quarter part of nakshatra");
+
 	double ra, dec;
 	StelUtils::rectToSphe(&ra, &dec, eqPos);
 	if (frameType==StelCore::FrameObservercentricEclipticOfDate)
@@ -479,12 +545,34 @@ QString StelSkyCultureSkyPartition::getLongitudeCoordinate(Vec3d &eqPos) const
 		if (partitions.at(0)==12)
 		{
 			double minuteInSign=(degreeInSign-floor(degreeInSign))*60.;
-			return QString("%1 %2°%3'").arg(symbols.at(sign), QString::number(int(floor(degreeInSign))), QString::number(int(floor(minuteInSign))));
+			if (narration)
+				return QString("%1, %2 %3, %4 %5 %6").arg(names.at(sign).getOneIdentifier(narration), QString::number(int(floor(degreeInSign))), sDegrees,
+									sAnd, QString::number(int(floor(minuteInSign))), sMinutes );
+			else
+				return QString("%1 %2°%3'").arg(symbols.at(sign), QString::number(int(floor(degreeInSign))), QString::number(int(floor(minuteInSign))));
 		}
 		else if (partitions.at(0)==27)
 		{
+			// Indian Nakshatras
 			int padaInSign=int(floor((degreeInSign/widthOfSign)*4.));
-			return QString("%1: %2").arg(symbols.at(sign), QString::number(int(floor(padaInSign+1))));
+			if (narration)
+				return QString("%1, %2 %3").arg(names.at(sign).getOneIdentifier(narration), sPada, QString::number(padaInSign+1));
+			else
+				return QString("%1: %2").arg(symbols.at(sign), QString::number(padaInSign+1));
+		}
+		else if (partitions.at(0)==28)
+		{
+			// Arab LM: Presumably a pragmatic three-partition is in use, like "not quite here yet", "central", "slightly past".
+			static StelSkyCultureMgr *scMgr=GETSTELMODULE(StelSkyCultureMgr);
+
+			int thirdInSign=int(floor((degreeInSign/widthOfSign)*3.));
+			if (narration)
+			{
+				const QStringList thirds({qc_("Begin of", "object narration"), qc_("Center of", "object narration"), qc_("End of", "object narration")});
+				return QString("%1, %2").arg(thirds[thirdInSign], names.at(sign).getOneIdentifier(narration));
+			}
+			else
+				return QString("%1: %2").arg(scMgr->createCulturalLabel(names.at(sign), scMgr->getScreenLabelStyle(), QString()), QString::number(thirdInSign+1));
 		}
 		else
 		{
@@ -522,9 +610,11 @@ QString StelSkyCultureSkyPartition::getLongitudeCoordinate(Vec3d &eqPos) const
 				break;
 			++mansion;
 		}
-		QString mnName=scMgr->createCulturalLabel(names.at(mansion), scMgr->getScreenLabelStyle(), names.at(mansion).pronounceI18n);
+		QString mnName=scMgr->createCulturalLabel(names.at(mansion), scMgr->getScreenLabelStyle(), names.at(mansion).getOneIdentifier(narration));
 
-
-		return QString("%1 - %2").arg(symbols.at(mansion), mnName);
+		if (narration)
+			return names.at(mansion).getOneIdentifier(narration);
+		else
+			return QString("%1 - %2").arg(symbols.at(mansion), mnName);
 	}
 }
