@@ -99,6 +99,8 @@ constexpr double DEFAULT_FONT_SIZE = 13;
 //! @namespace StelUtils contains general purpose utility functions.
 namespace StelUtils
 {
+	static inline constexpr double J2000 = 2451545.0;
+
 	//! Return the full name of stellarium, i.e. "Stellarium 23.1"
 	QString getApplicationName();
 
@@ -117,6 +119,9 @@ namespace StelUtils
 	//! Return the user agent name, i.e. "Stellarium/0.15.0 (Linux)"
 	QString getUserAgentString();
 
+        //! Return the addressing mode string, i.e. "64-bit"
+        QString getAddressingMode();
+
 	/*! \brief Get a long integer from a JSON value
 	 *
 	 *  QJsonValue stores JSON numbers as double-precision floating-point values. This means
@@ -190,6 +195,12 @@ namespace StelUtils
 	//! @param useD Define if letter "d" must be used instead of deg sign
 	//! @param positive Define if function should use 0-360 degrees
 	QString radToDecDegStr(const double angle, const int precision = 4, const bool useD=false, const bool positive=false);
+	//! Convert an angle in radian to a decimal degree string for narration.
+	//! @param angle input angle in radian
+	//! @param precision
+	//! @param useD (ignored)
+	//! @param positive Define if function should use 0-360 degrees
+	QString radToDecDegNarration(const double angle, const int precision = 4, const bool useD=false, const bool positive=false);
 
 	//! Convert an angle in radian to a hms formatted string.
 	//! If the second, minute part is == 0, it is not output
@@ -200,6 +211,10 @@ namespace StelUtils
 	//! @param angle input angle in radian
 	//! @param decimal output decimal second value
 	QString radToHmsStr(const double angle, const bool decimal=false);
+	//! Convert an angle in radian to a hms formatted string for narration.
+	//! @param angle input angle in radian
+	//! @param decimal output decimal second value
+	QString radToHmsNarration(const double angle, const bool decimal=false);
 
 	//! Convert an angle in radian to a dms formatted string.
 	//! If the second, minute part is == 0, it is not output
@@ -212,12 +227,22 @@ namespace StelUtils
 	//! @param decimal output second value with decimal fraction
 	//! @param useD Define if letter "d" must be used instead of deg sign
 	QString radToDmsStr(const double angle, const bool decimal=false, const bool useD=false);
+	//! Convert an angle in radian to a dms formatted string for narration.
+	//! @param angle input angle in radian
+	//! @param decimal output second value with decimal fraction
+	//! @param useD (ignored)
+	QString radToDmsNarration(const double angle, const bool decimal=false, const bool useD=false);
 
 	//! Convert an angle in radian to a dms formatted string.
 	//! @param angle input angle in radian
 	//! @param precision
 	//! @param useD Define if letter "d" must be used instead of deg sign
 	QString radToDmsPStr(const double angle, const int precision = 0, const bool useD=false);
+	//! Convert an angle in radian to a dms formatted string for narration.
+	//! @param angle input angle in radian
+	//! @param precision
+	//! @param useD (ignored)
+	QString radToDmsPNarration(const double angle, const int precision = 0, const bool useD=false);
 
 	//! Convert an angle in decimal degree to +-dms format.
 	//! @param angle input angle in decimal degree
@@ -230,11 +255,19 @@ namespace StelUtils
 	//! Convert an angle in decimal degrees to a dms formatted string.
 	//! @param angle input angle in decimal degrees
 	QString decDegToDmsStr(const double angle);
+	//! Convert an angle in decimal degrees to a dms formatted string for narration.
+	//! @param sayPlus true if the positivw sign really should be spoken
+	QString decDegToDmsNarration(const double angle, bool sayPlus=false);
 
 	//! Convert latitude in decimal degrees to a dms formatted string or use decimal values.
 	//! @param latitude in decimal degrees
 	//! @param dms set true to use DMS formatted string
 	QString decDegToLatitudeStr(const double latitude, bool dms = true);
+	//! Convert latitude in decimal degrees to a dms formatted string or use decimal values. Interface equals decDegToLatitudeStr().
+	//! @param latitude in decimal degrees
+	//! @param dms set true to use DMS formatted string
+	QString decDegToLatitudeNarration(const double latitude, bool dms = true);
+
 
 	//! Convert longitude in decimal degrees to a dms formatted string.
 	//! @param longitude in decimal degrees
@@ -242,6 +275,12 @@ namespace StelUtils
 	//! @param semiSphere set true to use -180..180 degrees range (0..360 degrees otherwise)
 	//! @param dms set true to use DMS formatted string
 	QString decDegToLongitudeStr(const double longitude, bool eastPositive = true, bool semiSphere = true, bool dms = true);
+	//! Convert longitude in decimal degrees to a narration-ready string. Interface equals decDegToLongitudeStr().
+	//! @param longitude in decimal degrees
+	//! @param eastPositive set true to counting East direction positive
+	//! @param semiSphere set true to use -180..180 degrees range (0..360 degrees otherwise)
+	//! @param dms set true to use DMS formatted string
+	QString decDegToLongitudeNarration(const double longitude, bool eastPositive = true, bool semiSphere = true, bool dms = true);
 
 	//! Convert a dms formatted string to an angle in radian
 	//! @param s The input string
@@ -612,13 +651,31 @@ namespace StelUtils
 
 	//! Convert decimal hours to hours, minutes, seconds
 	//! Format for:
-	//! @p colonFormat        |      false     |   true
+	//! @p minutesOnly        |      false     |   true
 	//! ----------------------|----------------|----------
-	//! @p minutesOnly=false  |  "HhMMmSS.Ss"  | "HHhMMm"
-	//! @p minutesOnly=true   |  "H:MM:SS.S"   | "HH:MM"
+	//! @p colonFormat=false  |  "HhMMmSS.Ss"  | "HHhMMm"
+	//! @p colonFormat=true   |  "H:MM:SS.S"   | "HH:MM"
 	QString hoursToHmsStr(const double hours, const bool minutesOnly = false, const bool colonFormat=false);
 	QString hoursToHmsStr(const float hours, const bool minutesOnly = false, const bool colonFormat=false);
 
+	//! Convert decimal hours to hours, minutes, seconds in a narrate-ready long format
+	//! Format for:
+	//! @p minutesOnly        |      false                               |   true
+	//! ----------------------|------------------------------------------|----------
+	//!                       |  "H hours, MM minutes and SS.S seconds"  | "HH hours and MM minutes"
+	//! @p colonFormat is ignored (only kept for signature compatibility)
+	QString hoursToHmsNarration(const double hours, const bool minutesOnly = false, const bool colonFormat=false);
+	QString hoursToHmsNarration(const float hours, const bool minutesOnly = false, const bool colonFormat=false);
+
+	//QString hoursToNarration(const double hours, const bool minutesOnly = false); // OBSOLETE? TOO CONFUSE NAME.
+	//QString hoursToNarration(const float hours, const bool minutesOnly = false);
+
+	//! Construct a speech-ready wording for ordinary floating point numbers.
+	//! Accounts for
+	//! - Minus sign
+	//! - dot versus comma
+	QString narrateDecimal(double num, int decimals=2);
+
 	//! Convert JD to hours and minutes
 	QString getHoursMinutesFromJulianDay(const double julianDay);
 
@@ -627,6 +684,8 @@ namespace StelUtils
 
 	//! Convert days (float) to a time string
 	QString daysFloatToDHMS(float days);
+	//! Convert days (float) to a time string ready for speech output
+	QString daysFloatToDHMSnarration(float days);
 
 	//! The method to splitting the text by substrings by some limit of string length
 	QString wrapText(const QString& s, const int limit = 52);
@@ -1062,6 +1121,9 @@ namespace StelUtils
 		typedef Result result_type;
 	};
 
+	//! Convert otherwise unspeakable (usually) Greek characters from star labels (Bayer, Struve, ...) into speech compatible output.
+	//! When preparing speech output, just apply this as filter.
+	QString narrateGreekChars(const QString &input);
 
 #ifdef _MSC_BUILD
 	inline double trunc(double x)
