@@ -33,7 +33,6 @@
 #include "StelMovementMgr.hpp"
 #include "StelModuleMgr.hpp"
 #include "LandscapeMgr.hpp"
-#include "StelLocaleMgr.hpp"
 
 #include <QDebug>
 #include <QElapsedTimer>
@@ -89,11 +88,9 @@ Comet::Comet(const QString& englishName,
 		  pTypeStr),
 	  slopeParameter(-10.f), // -10 == uninitialized: used in getVMagnitude()
 	  isCometFragment(false),
-	  iauDesignation(""),
+	  iauDesignation(QString()),
 	  extraDesignations(),
 	  extraDesignationsHtml(),
-	  discoverer(""),
-	  discoveryDate(""),
 	  tailFactors(-1., -1.), // mark "invalid"
 	  tailActive(false),
 	  tailBright(false),
@@ -255,15 +252,6 @@ QVariantMap Comet::getInfoMap(const StelCore *core) const
 	return map;
 }
 
-QString Comet::getDiscoveryCircumstances() const
-{
-	QString ddate = StelUtils::localeDiscoveryDateString(discoveryDate);
-	if (discoverer.isEmpty())
-		return ddate;
-	else
-		return QString("%1 (%2)").arg(ddate, discoverer);
-}
-
 double Comet::getSiderealPeriod() const
 {
 	const double semiMajorAxis=static_cast<KeplerOrbit*>(orbitPtr)->getSemimajorAxis();
@@ -466,7 +454,7 @@ void Comet::draw(StelCore* core, float maxMagLabels, const QFont& planetNameFont
 	const float vMagnitude=getVMagnitude(core);
 
 	// Exclude drawing if user set a hard limit magnitude.
-	if (core->getSkyDrawer()->getFlagPlanetMagnitudeLimit() && (vMagnitude > core->getSkyDrawer()->getCustomPlanetMagnitudeLimit()))
+	if (core->getSkyDrawer()->getFlagPlanetMagnitudeLimit() && (vMagnitude > static_cast<float>(core->getSkyDrawer()->getCustomPlanetMagnitudeLimit())))
 		return;
 
 	if (getEnglishName() == core->getCurrentLocation().planetName)
@@ -516,7 +504,8 @@ void Comet::draw(StelCore* core, float maxMagLabels, const QFont& planetNameFont
 			StelPainter sPainter(prjin);
 			drawHints(core, sPainter, planetNameFont);
 			Vec3f color=Vec3f(0.25, 0.75, 1);
-			ss->drawAsteroidMarker(core, &sPainter, screenPos[0], screenPos[1], color); // This does not draw directly, but record an entry to be drawn in a batch.
+			if (vMagnitude < ss->getMarkerMagThreshold())
+				ss->drawAsteroidMarker(core, &sPainter, screenPos[0], screenPos[1], color); // This does not draw directly, but record an entry to be drawn in a batch.
 		}
 
 		draw3dModel(core,transfo,static_cast<float>(screenRd), 1.0);
@@ -697,7 +686,7 @@ void Comet::setIAUDesignation(const QString& designation)
 void Comet::setExtraDesignations(QStringList codes)
 {
 	extraDesignations = codes;
-	for (const auto& c : codes)
+	for (const auto& c : std::as_const(codes))
 	{
 		extraDesignationsHtml << renderDiscoveryDesignationHtml(c);
 	}
