@@ -32,6 +32,7 @@
 #include "StelPainter.hpp"
 #include "RefractionExtinction.hpp"
 #include "StelSkyCultureMgr.hpp"
+#include "ConstellationMgr.hpp"
 
 #include <QTextStream>
 #include <QFile>
@@ -1695,3 +1696,220 @@ Vec3d Nebula::getJ2000EquatorialPos(const StelCore* core) const
 		return XYZ;
 	}
 }
+
+// Implemented:
+// * Name
+// * CatalogNumber
+// * Magnitude
+// RaDecJ2000
+// RaDecOfDate
+// AltAzi
+// * Distance
+// Elongation
+// Size
+// Velocity
+// ProperMotion
+// Extra
+// HourAngle
+// * AbsoluteMagnitude
+// GalacticCoord
+// SupergalacticCoord
+// OtherCoord
+// * ObjectType
+// EclipticCoordJ2000
+// EclipticCoordOfDate
+// * IAUConstellation
+// - CulturalConstellation
+// SiderealTime
+// RTSTime
+// SolarLunarPosition
+QString Nebula::getNarration(const StelCore *core, const InfoStringGroup &flags) const
+{
+	const Vec3d pos = getEquinoxEquatorialPos(core);
+
+	QString res;
+
+	// Name
+	const QString designation = getDSODesignationWIC();
+	QStringList names = {getNameI18n()};
+	if (culturalNames.length()>0)
+	{
+		for (const StelObject::CulturalName &cName: culturalNames)
+			names.append(cName.translatedI18n);
+	}
+	names.removeDuplicates();
+	names.removeAll("");
+
+	if (flags&Name)
+	{
+		res=designation;
+		if (!names.isEmpty())
+			res.append(", " +  q_("called") + " " + names.first() + ","); // TBD: Provide more than 1 name?
+	}
+	if (flags&ObjectType)// Type
+		res.append(" " + q_("is") + " " + typeI18nNebulaStringMap.value(nType, qc_("an object of unknown type", "Nebula narration")) );
+
+	if (flags&Distance)// Distance. Taken from getInfoString. Maybe move that to a private method...
+	{
+		if (qAbs(parallax)>0.f)
+		{
+			QString dx;
+			// distance in light years from parallax
+			float distance = 3.162e-5f/(qAbs(parallax)*4.848e-9f);
+			float distanceErr = 0.f;
+
+			if (parallaxErr>0.f)
+				distanceErr = qAbs(3.162e-5f/(qAbs(parallaxErr + parallax)*4.848e-9f) - distance);
+
+			if (distanceErr>0.f)
+				dx = QString("%1%2%3").arg(StelUtils::narrateDecimal(distance, 3)).arg(QChar(0x00B1)).arg(StelUtils::narrateDecimal(distanceErr, 3));
+			else
+				dx = QString("%1").arg(StelUtils::narrateDecimal(distance, 3));
+
+			if (oDistance==0.f)
+			{
+				// TRANSLATORS: Unit of measure for distance - Light Years
+				QString ly = qc_("light years", "distance");
+				res.append(QString("%1 %2 %3").arg(qc_("in a distance of", "object narration"), dx, ly));
+			}
+		}
+		if (oDistance>0.f)
+		{
+			QString dx, dy;
+			float dc = 3262.f;
+			int ms = 1;
+			//TRANSLATORS: Unit of measure for distance - kiloparsecs
+			QString dupc = qc_("kiloparsec", "object narration");
+			//TRANSLATORS: Unit of measure for distance - Light Years
+			QString duly = qc_("light years", "object narration");
+
+			float distance = oDistance;
+			float distanceErr = oDistanceErr;
+			float distanceLY = oDistance*dc;
+			float distanceErrLY= oDistanceErr*dc;
+			if (oDistance>=1000.f)
+			{
+				distance = oDistance/1000.f;
+				distanceErr = oDistanceErr/1000.f;
+				//TRANSLATORS: Unit of measure for distance - Megaparsecs
+				dupc = qc_("Megaparsec", "object narration");
+			}
+
+			if (distanceLY>=1e6f)
+			{
+				distanceLY /= 1e6f;
+				distanceErrLY /= 1e6f;
+				ms = 3;
+				//TRANSLATORS: Unit of measure for distance - Millions of Light Years
+				duly = qc_("Million light years", "object narration");
+			}
+
+			if (oDistanceErr>0.f)
+			{
+				dx = QString("%1%2%3").arg(StelUtils::narrateDecimal(distance, 3)).arg(QChar(0x00B1)).arg(StelUtils::narrateDecimal(distanceErr, 3));
+				dy = QString("%1%2%3").arg(StelUtils::narrateDecimal(distanceLY, ms)).arg(QChar(0x00B1)).arg(StelUtils::narrateDecimal(distanceErrLY, ms));
+			}
+			else
+			{
+				dx = QString("%1").arg(StelUtils::narrateDecimal(distance, 3));
+				dy = QString("%1").arg(StelUtils::narrateDecimal(distanceLY, ms));
+			}
+
+			res.append(QString("%1 %2 %3 (%4 %5)").arg(qc_("in a distance of", "object narration"), dx, dupc, dy, duly));
+		}
+	}
+
+	if (flags&IAUConstellation) // IAU Constellation
+	{
+		const QString iauConstellation = ConstellationMgr::getIAUconstellationName(core->getIAUConstellation(pos));
+		res.append(" " + qc_("in the constellation of", "object narration") + " " + iauConstellation + ". ");
+	}
+
+	if (flags&Extra) // redshift, parallax, Discovery
+	{
+		if (redshift<99.f && nType<=NebQSO) // useful for galaxy types only.
+		{
+			QString z;
+			if (redshiftErr>0.f)
+				z = QString("%1 %2 %3").arg(StelUtils::narrateDecimal(redshift, 6), qc_("plus minus", "object narration"), StelUtils::narrateDecimal(redshiftErr, 6));
+			else
+				z = QString("%1").arg(StelUtils::narrateDecimal(redshift, 6));
+
+			res += QString("%1 %2").arg(qc_("Its redshift is", "object narration"), z);
+		}
+		if (qAbs(parallax)>0.5f)
+		{
+			QString px;
+			if (parallaxErr>0.f)
+				px = QString("%1 %2 %3").arg(StelUtils::narrateDecimal(qAbs(parallax), 3), qc_("plus minus", "object narration"), StelUtils::narrateDecimal(parallaxErr, 3));
+			else
+				px = QString("%1").arg(StelUtils::narrateDecimal(qAbs(parallax), 3));
+
+			res += QString("%1 %2 %3").arg(qc_("Its Parallax", "object narration"), px, qc_("milli-arcseconds", "parallax"));
+		}
+
+
+		if (!discoverer.isEmpty())
+		{
+			res.append(qc_("It was discovered by", "object narration") + " " + discoverer);
+			if (!discoveryYear.isEmpty())
+				res.append(" " + qc_("in the year", "object narration") + " " + discoveryYear);
+			res.append(". ");
+		}
+
+		// Shape
+		QString morph=getMorphologicalTypeDescription();
+		if (!morph.isEmpty())
+		{
+			res.append(qc_("Morphologically:", "object narration") + " " + morph + ".");
+		}
+	}
+	return res;
+}
+
+QMap<Nebula::NebulaType, QString>Nebula::typeI18nNebulaStringMap;
+
+void Nebula::updateI18n()
+{
+	// The word forms should be with article if needed by the language
+	typeI18nNebulaStringMap=
+	{
+		{ Nebula::NebGx			,  qc_("a Galaxy", "Nebula narration")},
+		{ Nebula::NebAGx		,  qc_("an Active galaxy", "Nebula narration")},
+		{ Nebula::NebRGx		,  qc_("a Radio galaxy", "Nebula narration")},
+		{ Nebula::NebIGx		,  qc_("an Interacting galaxy", "Nebula narration")},
+		{ Nebula::NebQSO		,  qc_("a Quasar", "Nebula narration")},
+		{ Nebula::NebCl			,  qc_("a Star cluster", "Nebula narration")},
+		{ Nebula::NebOc			,  qc_("an Open star cluster", "Nebula narration")},
+		{ Nebula::NebGc			,  qc_("a Globular star cluster", "Nebula narration")},
+		{ Nebula::NebSA			,  qc_("a Stellar association", "Nebula narration")},
+		{ Nebula::NebSC			,  qc_("a Star cloud", "Nebula narration")},
+		{ Nebula::NebN			,  qc_("A nebula", "Nebula narration")},
+		{ Nebula::NebPn			,  qc_("a Planetary nebula", "Nebula narration")},
+		{ Nebula::NebDn			,  qc_("a Dark Nebula", "Nebula narration")},
+		{ Nebula::NebRn			,  qc_("a Reflection nebula", "Nebula narration")},
+		{ Nebula::NebBn			,  qc_("a Bipolar nebula", "Nebula narration")},
+		{ Nebula::NebEn			,  qc_("an emission nebula", "Nebula narration")},
+		{ Nebula::NebCn			,  qc_("a cluster associated with nebulosity", "Nebula narration")},
+		{ Nebula::NebHII		,  qc_("H two region", "Nebula narration")},
+		{ Nebula::NebSNR		,  qc_("a Supernova remnant", "Nebula narration")},
+		{ Nebula::NebISM		,  qc_("Interstellar matter", "Nebula narration")},
+		{ Nebula::NebEMO		,  qc_("an Emission object", "Nebula narration")},
+		{ Nebula::NebBLL		,  qc_("a BL Lacertae object", "Nebula narration")},
+		{ Nebula::NebBLA		,  qc_("a Blazar", "Nebula narration")},
+		{ Nebula::NebMolCld		,  qc_("a Molecular Cloud", "Nebula narration")},
+		{ Nebula::NebYSO		,  qc_("a Young Stellar Object", "Nebula narration")},
+		{ Nebula::NebPossQSO		,  qc_("a Possible Quasar", "Nebula narration")},
+		{ Nebula::NebPossPN		,  qc_("a Possible Planetary Nebula", "Nebula narration")},
+		{ Nebula::NebPPN		,  qc_("a Protoplanetary Nebula", "Nebula narration")},
+		{ Nebula::NebStar		,  qc_("a Star", "Nebula narration")},
+		{ Nebula::NebSymbioticStar	,  qc_("a Symbiotic Star", "Nebula narration")},
+		{ Nebula::NebEmissionLineStar	,  qc_("an Emission-line Star", "Nebula narration")},
+		{ Nebula::NebSNC		,  qc_("a Supernova Candidate", "Nebula narration")},
+		{ Nebula::NebSNRC		,  qc_("a supernova Remnant Candidate", "Nebula narration")},
+		{ Nebula::NebGxCl		,  qc_("a cluster of Galaxies", "Nebula narration")},
+		{ Nebula::NebPartOfGx		,  qc_("a part of a Galaxy", "Nebula narration")},
+		{ Nebula::NebRegion		,  qc_("a region of the sky", "Nebula narration")},
+		{ Nebula::NebUnknown		,  qc_("an object of unknown type", "Nebula narration")}
+	};
+}
