@@ -78,63 +78,63 @@ QString NomenclatureItem::getNomenclatureTypeString(NomenclatureItemType nType)
 QString NomenclatureItem::getNomenclatureTypeLatinString(NomenclatureItemType nType)
 {
 	static const QMap<NomenclatureItemType, QString>map = {
-		{ niSpecialPointPole, "point" },
-		{ niSpecialPointEast, "point" },
-		{ niSpecialPointWest, "point" },
-		{ niSpecialPointCenter, "point" },
-		{ niSpecialPointSubSolar, "point" },
-		{ niArcus  , "arcus" },
-		{ niAstrum , "astrum" },
-		{ niCatena , "catena" },
-		{ niCavus  , "cavus" },
-		{ niChaos  , "chaos" },
-		{ niChasma , "chasma" },
-		{ niCollis , "collis" },
-		{ niCorona , "corona" },
-		{ niCrater , "crater" },
-		{ niDorsum , "dorsum" },
-		{ niFacula , "facula" },
-		{ niFarrum , "farrum" },
-		{ niFlexus , "flexus" },
-		{ niFluctus, "fluctus" },
-		{ niFlumen , "flumen" },
-		{ niFretum , "fretum" },
-		{ niFossa  , "fossa" },
-		{ niInsula , "insula" },
-		{ niLabes  , "labes" },
-		{ niLabyrinthus, "labyrinthus" },
-		{ niLacuna   , "lacuna" },
-		{ niLacus    , "lacus" },
-		{ niLenticula, "lenticula" },
-		{ niLinea    , "linea" },
-		{ niLingula  , "lingula" },
-		{ niMacula   , "macula" },
-		{ niMare     , "mare" },
-		{ niMensa    , "mensa" },
-		{ niMons     , "mons" },
-		{ niOceanus  , "oceanus" },
-		{ niPalus    , "palus" },
-		{ niPatera   , "patera" },
-		{ niPlanitia , "planitia" },
-		{ niPlanum   , "planum" },
-		{ niPlume    , "plume" },
-		{ niPromontorium, "promontorium" },
-		{ niRegio    , "regio" },
-		{ niReticulum, "reticulum" },
-		{ niRima     , "rima" },
-		{ niRupes    , "rupes" },
-		{ niSaxum  , "saxum" },
-		{ niScopulus , "scopulus" },
-		{ niSerpens  , "serpens" },
-		{ niSulcus   , "sulcus" },
-		{ niSinus    , "sinus" },
-		{ niTerra    , "terra" },
-		{ niTessera  , "tessera" },
-		{ niTholus   , "tholus" },
-		{ niUnda     , "unda" },
-		{ niVallis   , "vallis" },
-		{ niVastitas , "vastitas" },
-		{ niVirga    , "virga" }};
+		{ niSpecialPointPole    , L1S("point") },
+		{ niSpecialPointEast    , L1S("point") },
+		{ niSpecialPointWest    , L1S("point") },
+		{ niSpecialPointCenter  , L1S("point") },
+		{ niSpecialPointSubSolar, L1S("point") },
+		{ niArcus               , L1S("arcus") },
+		{ niAstrum              , L1S("astrum") },
+		{ niCatena              , L1S("catena") },
+		{ niCavus               , L1S("cavus") },
+		{ niChaos               , L1S("chaos") },
+		{ niChasma              , L1S("chasma") },
+		{ niCollis              , L1S("collis") },
+		{ niCorona              , L1S("corona") },
+		{ niCrater              , L1S("crater") },
+		{ niDorsum              , L1S("dorsum") },
+		{ niFacula              , L1S("facula") },
+		{ niFarrum              , L1S("farrum") },
+		{ niFlexus              , L1S("flexus") },
+		{ niFluctus             , L1S("fluctus") },
+		{ niFlumen              , L1S("flumen") },
+		{ niFretum              , L1S("fretum") },
+		{ niFossa               , L1S("fossa") },
+		{ niInsula              , L1S("insula") },
+		{ niLabes               , L1S("labes") },
+		{ niLabyrinthus         , L1S("labyrinthus") },
+		{ niLacuna              , L1S("lacuna") },
+		{ niLacus               , L1S("lacus") },
+		{ niLenticula           , L1S("lenticula") },
+		{ niLinea               , L1S("linea") },
+		{ niLingula             , L1S("lingula") },
+		{ niMacula              , L1S("macula") },
+		{ niMare                , L1S("mare") },
+		{ niMensa               , L1S("mensa") },
+		{ niMons                , L1S("mons") },
+		{ niOceanus             , L1S("oceanus") },
+		{ niPalus               , L1S("palus") },
+		{ niPatera              , L1S("patera") },
+		{ niPlanitia            , L1S("planitia") },
+		{ niPlanum              , L1S("planum") },
+		{ niPlume               , L1S("plume") },
+		{ niPromontorium        , L1S("promontorium") },
+		{ niRegio               , L1S("regio") },
+		{ niReticulum           , L1S("reticulum") },
+		{ niRima                , L1S("rima") },
+		{ niRupes               , L1S("rupes") },
+		{ niSaxum               , L1S("saxum") },
+		{ niScopulus            , L1S("scopulus") },
+		{ niSerpens             , L1S("serpens") },
+		{ niSulcus              , L1S("sulcus") },
+		{ niSinus               , L1S("sinus") },
+		{ niTerra               , L1S("terra") },
+		{ niTessera             , L1S("tessera") },
+		{ niTholus              , L1S("tholus") },
+		{ niUnda                , L1S("unda") },
+		{ niVallis              , L1S("vallis") },
+		{ niVastitas            , L1S("vastitas") },
+		{ niVirga               , L1S("virga") }};
 		return map.value(nType, "");
 }
 
@@ -143,10 +143,10 @@ QString NomenclatureItem::getNomenclatureTypeDescription(NomenclatureItemType nT
 	Q_ASSERT(niTypeDescriptionMap.size()>20); // should be filled, not sure how many.
 	QString ret=niTypeDescriptionMap.value(nType, q_("Undocumented landform type."));
 	// Fix a few exceptions
-	if((englishName=="Mars") && (nType==niMare))
+	if((englishName==L1S("Mars")) && (nType==niMare))
 		// TRANSLATORS: Description for landform 'mare' on Mars
 		return q_("'Sea'; dark albedo areas of no known geological significance.");
-	if (englishName=="Titan")
+	if (englishName==L1S("Titan"))
 	{
 		if (nType==niLacus)
 			// TRANSLATORS: Description for landform 'lacus' on Titan
@@ -248,12 +248,12 @@ QString NomenclatureItem::getInfoString(const StelCore* core, const InfoStringGr
 		oss << QString("%1: %2 %3<br/>").arg(sz, QString::number(size, 'f', 2), qc_("km", "distance"));
 	}
 
-	if (flags&Extra)
+	if (flags&OtherCoord)
 	{
 		const QString cType = isPlanetocentric() ? q_("Planetocentric coordinates") : q_("Planetographic coordinates");
 		QString sLong = StelUtils::decDegToLongitudeStr(longitude, isEastPositive(), is180(), !withDecimalDegree),
 			sLat  = StelUtils::decDegToLatitudeStr(latitude, !withDecimalDegree);
-		if (nType>=NomenclatureItemType::niSpecialPointEast && planet->getEnglishName()=="Jupiter")
+		if (nType>=NomenclatureItemType::niSpecialPointEast && planet->getEnglishName()==L1S("Jupiter"))
 		{
 			// Due to Jupiter's issues around GRS shift we must repeat some calculations here.
 			double lng=0., lat=0.;
@@ -280,9 +280,11 @@ QString NomenclatureItem::getInfoString(const StelCore* core, const InfoStringGr
 		QString description = getNomenclatureTypeDescription(nType, planet->getEnglishName());
 		if (nType!=NomenclatureItem::niUNDEFINED && nType<NomenclatureItem::niSpecialPointPole && !description.isEmpty())
 			oss << QString("%1: %2<br/>").arg(q_("Landform description"), description);
-		if (planet->getEnglishName()!="Jupiter") // we must exclude this for now due to Jupiter's "off" rotation
+		if (planet->getEnglishName()!=L1S("Jupiter")) // we must exclude this for now due to Jupiter's "off" rotation
 			oss << QString("%1: %2°<br/>").arg(q_("Solar altitude"), QString::number(getSolarAltitude(core), 'f', 1));
-
+	}
+	if (flags&Extra)
+	{
 		if (!origin.isEmpty())
 			oss << StelUtils::wrapText(QString("%1: %2").arg(q_("Origin of name"), originI18n)) << "<br/>";
 
@@ -296,6 +298,122 @@ QString NomenclatureItem::getInfoString(const StelCore* core, const InfoStringGr
 	return str;
 }
 
+QString NomenclatureItem::getNarration(const StelCore* core, const InfoStringGroup& flags) const
+{
+	QString str;
+	QTextStream oss(&str);
+	const bool withDecimalDegree = StelApp::getInstance().getFlagShowDecimalDegrees();
+
+	if (flags&Name)
+	{
+		oss << nameI18n;
+		// englishName here is the original scientific term, usually latin but could be plain english like "landing site".
+		if (nameI18n!=englishName && nType<NomenclatureItemType::niSpecialPointPole)
+			oss << qc_("or", "object narration") << " " << englishName;
+		oss << ". ";
+	}
+
+	if (flags&ObjectType && nType!=NomenclatureItem::niUNDEFINED)
+	{
+		const QString typeStr=getNomenclatureTypeString(nType);
+		const QString latinTypeStr=getNomenclatureTypeLatinString(nType);
+		const QString description = getNomenclatureTypeDescription(nType, planet->getEnglishName()); // TODO Needs articles etc?
+		const bool onTheMoon=planet->getEnglishName()==L1S("Moon");
+
+		if (onTheMoon)
+		{
+			if (typeStr!=latinTypeStr)
+			{
+				if (nType!=NomenclatureItem::niUNDEFINED && nType<NomenclatureItem::niSpecialPointPole && !description.isEmpty())
+					oss << " " << QString(qc_("is a %1 (or %2), that is: %3, on the Moon", "object narration")).arg(typeStr, latinTypeStr, description);
+				else
+					oss << " " << QString(qc_("is a %1 (or %2), on the Moon", "object narration")).arg(typeStr, latinTypeStr);
+			}
+			else
+			{
+				if (nType!=NomenclatureItem::niUNDEFINED && nType<NomenclatureItem::niSpecialPointPole && !description.isEmpty())
+					oss << " " << QString(qc_("is a %1, that is: %2, on the Moon", "object narration")).arg(typeStr, description);
+				else
+					oss << " " << QString(qc_("is a %1 on the Moon", "object narration")).arg(typeStr);
+			}
+		}
+		else
+		{
+			if (typeStr!=latinTypeStr)
+			{
+				if (nType!=NomenclatureItem::niUNDEFINED && nType<NomenclatureItem::niSpecialPointPole && !description.isEmpty())
+					oss << " " << QString(qc_("is a %1 (or %2), that is: %3, on %4", "object narration")).arg(typeStr, latinTypeStr, description, planet->getNameI18n());
+				else
+					oss << " " << QString(qc_("is a %1 (or %2), on %3", "object narration")).arg(typeStr, latinTypeStr, planet->getNameI18n());
+			}
+			else
+			{
+				if (nType!=NomenclatureItem::niUNDEFINED && nType<NomenclatureItem::niSpecialPointPole && !description.isEmpty())
+					oss << " " << QString(qc_("is a %1, that is: %2, on %3", "object narration")).arg(typeStr, description, planet->getNameI18n());
+				else
+					oss << " " << QString(qc_("is a %1 on %2", "object narration")).arg(typeStr, planet->getNameI18n());
+			}
+		}
+	}
+
+	// TODO Ra/Dec etc.
+	//oss << getCommonInfoString(core, flags);
+
+	if (flags&Size && size>0. && nType<NomenclatureItem::niSpecialPointPole)
+	{
+		// Satellite Features are almost(?) exclusively lettered craters, and all are on the Moon. Assume craters.
+		QString sz = ((nType==NomenclatureItem::niCrater) || (nType==NomenclatureItem::niSatelliteFeature)) ?
+			qc_("Its diameter is %1 kilometers", "object narration") : q_("It extends over %1 kilometers");
+		oss << QString(sz).arg(StelUtils::narrateDecimal(size, 2)) << ". ";
+	}
+
+	if (flags&Extra)
+	{
+		if (!origin.isEmpty())
+			oss << QString("%1: %2. ").arg(qc_("The feature was named after", "object narration"), originI18n);
+	}
+	if (flags&OtherCoord)
+	{
+		const QString cType = isPlanetocentric() ? qc_("Its planetocentric coordinates are", "object narration") : qc_("Its planetographic coordinates are", "object narration");
+		QString sLong = StelUtils::decDegToLongitudeNarration(longitude, isEastPositive(), is180(), !withDecimalDegree),
+			sLat  = StelUtils::decDegToLatitudeNarration(latitude, !withDecimalDegree);
+		if (nType>=NomenclatureItemType::niSpecialPointEast && planet->getEnglishName()==L1S("Jupiter"))
+		{
+			// Due to Jupiter's issues around GRS shift we must repeat some calculations here.
+			double lng=0., lat=0.;
+			// East/West points are assumed to be along the equator, on the planet rim. Start with sub-observer point
+			if (nType==NomenclatureItemType::niSpecialPointEast || nType==NomenclatureItemType::niSpecialPointWest)
+			{
+				QPair<Vec4d, Vec3d> subObs = planet->getSubSolarObserverPoints(core, false);
+				lng = - subObs.first[2]  * M_180_PI + ((nType==NomenclatureItemType::niSpecialPointEast) ? 90. : -90.);
+				Q_ASSERT(lat==0.);
+			}
+			// Center and Subsolar points are similar.
+			if (nType==NomenclatureItemType::niSpecialPointCenter || nType==NomenclatureItemType::niSpecialPointSubSolar)
+			{
+				QPair<Vec4d, Vec3d> subObs = planet->getSubSolarObserverPoints(core, false);
+				lat =   M_180_PI * (nType==NomenclatureItemType::niSpecialPointCenter ? subObs.first[1]: subObs.second[1]);
+				lng = - M_180_PI * (nType==NomenclatureItemType::niSpecialPointCenter ? subObs.first[2]: subObs.second[2]);
+			}
+			lng   = StelUtils::fmodpos(lng, 360.);
+			sLong = StelUtils::decDegToLongitudeNarration(360.-lng, isEastPositive(), is180(), !withDecimalDegree);
+			sLat  = StelUtils::decDegToLatitudeNarration(lat, !withDecimalDegree);
+		}
+		oss << QString("%1: %2, %3 %4. ").arg(cType, sLat, qc_("and", "object narration"), sLong);
+
+		if (planet->getEnglishName()!=L1S("Jupiter")) // we must exclude this for now due to Jupiter's "off" rotation
+			oss << QString("%1 %2 %3. ").arg(qc_("Solar altitude over the feature is", "object narration"), StelUtils::narrateDecimal(getSolarAltitude(core), 1), qc_("degrees", "object narration"));
+
+		// DEBUG output. This should help defining valid criteria for selection priority.
+		// oss << QString("Planet angular size (semidiameter!): %1''<br/>").arg(QString::number(planet->getAngularSize(core)*3600.));
+		// oss << QString("Angular size: %1''<br/>").arg(QString::number(getAngularSize(core)*3600.));
+		// oss << QString("Angular size ratio: %1<br/>").arg(QString::number(static_cast<double>(getAngularDiameterRatio(core)), 'f', 5));
+	}
+
+	//postProcessInfoString(str, flags);
+	return str;
+}
+
 Vec3f NomenclatureItem::getInfoColor(void) const
 {
 	return color;
@@ -456,63 +574,63 @@ NomenclatureItem::NomenclatureItemType NomenclatureItem::getNomenclatureItemType
 {
 	// codes for types of features (details: https://planetarynames.wr.usgs.gov/DescriptorTerms)
 	static const QMap<QString, NomenclatureItem::NomenclatureItemType> niTypes = {
-		{ "AL", NomenclatureItem::niAlbedoFeature	},
-		{ "AR", NomenclatureItem::niArcus		},
-		{ "AS", NomenclatureItem::niAstrum		},
-		{ "CA", NomenclatureItem::niCatena		},
-		{ "CB", NomenclatureItem::niCavus		},
-		{ "CH", NomenclatureItem::niChaos		},
-		{ "CM", NomenclatureItem::niChasma		},
-		{ "CO", NomenclatureItem::niCollis		},
-		{ "CR", NomenclatureItem::niCorona		},
-		{ "AA", NomenclatureItem::niCrater		},
-		{ "DO", NomenclatureItem::niDorsum		},
-		{ "ER", NomenclatureItem::niEruptiveCenter	},
-		{ "FA", NomenclatureItem::niFacula		},
-		{ "FR", NomenclatureItem::niFarrum		},
-		{ "FE", NomenclatureItem::niFlexus		},
-		{ "FL", NomenclatureItem::niFluctus		},
-		{ "FM", NomenclatureItem::niFlumen		},
-		{ "FO", NomenclatureItem::niFossa		},
-		{ "FT", NomenclatureItem::niFretum		},
-		{ "IN", NomenclatureItem::niInsula		},
-		{ "LA", NomenclatureItem::niLabes		},
-		{ "LB", NomenclatureItem::niLabyrinthus		},
-		{ "LU", NomenclatureItem::niLacuna		},
-		{ "LC", NomenclatureItem::niLacus		},
-		{ "LF", NomenclatureItem::niLandingSite		},
-		{ "LG", NomenclatureItem::niLargeRingedFeature	},
-		{ "LE", NomenclatureItem::niLenticula		},
-		{ "LI", NomenclatureItem::niLinea		},
-		{ "LN", NomenclatureItem::niLingula		},
-		{ "MA", NomenclatureItem::niMacula		},
-		{ "ME", NomenclatureItem::niMare		},
-		{ "MN", NomenclatureItem::niMensa		},
-		{ "MO", NomenclatureItem::niMons		},
-		{ "OC", NomenclatureItem::niOceanus		},
-		{ "PA", NomenclatureItem::niPalus		},
-		{ "PE", NomenclatureItem::niPatera		},
-		{ "PL", NomenclatureItem::niPlanitia		},
-		{ "PM", NomenclatureItem::niPlanum		},
-		{ "PU", NomenclatureItem::niPlume		},
-		{ "PR", NomenclatureItem::niPromontorium	},
-		{ "RE", NomenclatureItem::niRegio		},
-		{ "RT", NomenclatureItem::niReticulum		},
-		{ "RI", NomenclatureItem::niRima		},
-		{ "RU", NomenclatureItem::niRupes		},
-		{ "SA", NomenclatureItem::niSaxum		},
-		{ "SF", NomenclatureItem::niSatelliteFeature	},
-		{ "SC", NomenclatureItem::niScopulus		},
-		{ "SE", NomenclatureItem::niSerpens		},
-		{ "SI", NomenclatureItem::niSinus		},
-		{ "SU", NomenclatureItem::niSulcus		},
-		{ "TA", NomenclatureItem::niTerra		},
-		{ "TE", NomenclatureItem::niTessera		},
-		{ "TH", NomenclatureItem::niTholus		},
-		{ "UN", NomenclatureItem::niUnda		},
-		{ "VA", NomenclatureItem::niVallis		},
-		{ "VS", NomenclatureItem::niVastitas		},
-		{ "VI", NomenclatureItem::niVirga		}};
+		{ L1S("AL"), NomenclatureItem::niAlbedoFeature	},
+		{ L1S("AR"), NomenclatureItem::niArcus		},
+		{ L1S("AS"), NomenclatureItem::niAstrum		},
+		{ L1S("CA"), NomenclatureItem::niCatena		},
+		{ L1S("CB"), NomenclatureItem::niCavus		},
+		{ L1S("CH"), NomenclatureItem::niChaos		},
+		{ L1S("CM"), NomenclatureItem::niChasma		},
+		{ L1S("CO"), NomenclatureItem::niCollis		},
+		{ L1S("CR"), NomenclatureItem::niCorona		},
+		{ L1S("AA"), NomenclatureItem::niCrater		},
+		{ L1S("DO"), NomenclatureItem::niDorsum		},
+		{ L1S("ER"), NomenclatureItem::niEruptiveCenter	},
+		{ L1S("FA"), NomenclatureItem::niFacula		},
+		{ L1S("FR"), NomenclatureItem::niFarrum		},
+		{ L1S("FE"), NomenclatureItem::niFlexus		},
+		{ L1S("FL"), NomenclatureItem::niFluctus		},
+		{ L1S("FM"), NomenclatureItem::niFlumen		},
+		{ L1S("FO"), NomenclatureItem::niFossa		},
+		{ L1S("FT"), NomenclatureItem::niFretum		},
+		{ L1S("IN"), NomenclatureItem::niInsula		},
+		{ L1S("LA"), NomenclatureItem::niLabes		},
+		{ L1S("LB"), NomenclatureItem::niLabyrinthus		},
+		{ L1S("LU"), NomenclatureItem::niLacuna		},
+		{ L1S("LC"), NomenclatureItem::niLacus		},
+		{ L1S("LF"), NomenclatureItem::niLandingSite		},
+		{ L1S("LG"), NomenclatureItem::niLargeRingedFeature	},
+		{ L1S("LE"), NomenclatureItem::niLenticula		},
+		{ L1S("LI"), NomenclatureItem::niLinea		},
+		{ L1S("LN"), NomenclatureItem::niLingula		},
+		{ L1S("MA"), NomenclatureItem::niMacula		},
+		{ L1S("ME"), NomenclatureItem::niMare		},
+		{ L1S("MN"), NomenclatureItem::niMensa		},
+		{ L1S("MO"), NomenclatureItem::niMons		},
+		{ L1S("OC"), NomenclatureItem::niOceanus		},
+		{ L1S("PA"), NomenclatureItem::niPalus		},
+		{ L1S("PE"), NomenclatureItem::niPatera		},
+		{ L1S("PL"), NomenclatureItem::niPlanitia		},
+		{ L1S("PM"), NomenclatureItem::niPlanum		},
+		{ L1S("PU"), NomenclatureItem::niPlume		},
+		{ L1S("PR"), NomenclatureItem::niPromontorium	},
+		{ L1S("RE"), NomenclatureItem::niRegio		},
+		{ L1S("RT"), NomenclatureItem::niReticulum		},
+		{ L1S("RI"), NomenclatureItem::niRima		},
+		{ L1S("RU"), NomenclatureItem::niRupes		},
+		{ L1S("SA"), NomenclatureItem::niSaxum		},
+		{ L1S("SF"), NomenclatureItem::niSatelliteFeature	},
+		{ L1S("SC"), NomenclatureItem::niScopulus		},
+		{ L1S("SE"), NomenclatureItem::niSerpens		},
+		{ L1S("SI"), NomenclatureItem::niSinus		},
+		{ L1S("SU"), NomenclatureItem::niSulcus		},
+		{ L1S("TA"), NomenclatureItem::niTerra		},
+		{ L1S("TE"), NomenclatureItem::niTessera		},
+		{ L1S("TH"), NomenclatureItem::niTholus		},
+		{ L1S("UN"), NomenclatureItem::niUnda		},
+		{ L1S("VA"), NomenclatureItem::niVallis		},
+		{ L1S("VS"), NomenclatureItem::niVastitas		},
+		{ L1S("VI"), NomenclatureItem::niVirga		}};
 	return niTypes.value(abbrev, NomenclatureItem::niUNDEFINED);
 }
 QMap<NomenclatureItem::NomenclatureItemType, QString> NomenclatureItem::niTypeStringMap;
@@ -523,9 +641,9 @@ NomenclatureItem::PlanetCoordinateOrientation NomenclatureItem::getPlanetCoordin
 	// Commented away where they are equal to te default value.
 	static const QMap<QString, NomenclatureItem::PlanetCoordinateOrientation> niPCOMap = {
 	//{"Amalthea"   , NomenclatureItem::pcoPlanetographicWest360 },
-	{"Ariel"      , NomenclatureItem::pcoPlanetocentricEast360 },
+	{L1S("Ariel")      , NomenclatureItem::pcoPlanetocentricEast360 },
 	//{"Callisto"   , NomenclatureItem::pcoPlanetographicWest360 },
-	{"Charon"     , NomenclatureItem::pcoPlanetocentricEast360 },
+	{L1S("Charon")     , NomenclatureItem::pcoPlanetocentricEast360 },
 	//{"Deimos"     , NomenclatureItem::pcoPlanetographicWest360 },
 	//{"Dione"      , NomenclatureItem::pcoPlanetographicWest360 },
 	//{"Enceladus"  , NomenclatureItem::pcoPlanetographicWest360 },
@@ -536,25 +654,25 @@ NomenclatureItem::PlanetCoordinateOrientation NomenclatureItem::getPlanetCoordin
 	//{"Iapetus"    , NomenclatureItem::pcoPlanetographicWest360 },
 	//{"Io"         , NomenclatureItem::pcoPlanetographicWest360 }, // Voyager/Galileo SSI
 	//{"Janus"      , NomenclatureItem::pcoPlanetographicWest360 },
-	{"Mars"       , NomenclatureItem::pcoPlanetocentricEast360 }, // MDIM 2.1
+	{L1S("Mars")       , NomenclatureItem::pcoPlanetocentricEast360 }, // MDIM 2.1
 	//{"Mercury"    , NomenclatureItem::pcoPlanetographicWest360 }, // Preliminary MESSENGER MESSENGER Team
 	//{"Mimas"      , NomenclatureItem::pcoPlanetographicWest360 },
-	{"Miranda"    , NomenclatureItem::pcoPlanetocentricEast360 },
-	{"Moon"       , NomenclatureItem::pcoPlanetographicEast180 }, // LOLA 2011 ULCN 2005
-	{"Oberon"     , NomenclatureItem::pcoPlanetocentricEast360 },
+	{L1S("Miranda")    , NomenclatureItem::pcoPlanetocentricEast360 },
+	{L1S("Moon")       , NomenclatureItem::pcoPlanetographicEast180 }, // LOLA 2011 ULCN 2005
+	{L1S("Oberon")     , NomenclatureItem::pcoPlanetocentricEast360 },
 	//{"Phobos"     , NomenclatureItem::pcoPlanetographicWest360 },
 	//{"Phoebe"     , NomenclatureItem::pcoPlanetographicWest360 },
-	{"Pluto"      , NomenclatureItem::pcoPlanetocentricEast360 },
+	{L1S("Pluto")      , NomenclatureItem::pcoPlanetocentricEast360 },
 	//{"Proteus"    , NomenclatureItem::pcoPlanetographicWest360 },
-	{"Puck"       , NomenclatureItem::pcoPlanetocentricEast360 },
+	{L1S("Puck")       , NomenclatureItem::pcoPlanetocentricEast360 },
 	//{"Rhea"       , NomenclatureItem::pcoPlanetographicWest360 },
 	//{"Tethys"     , NomenclatureItem::pcoPlanetographicWest360 },
 	//{"Thebe"      , NomenclatureItem::pcoPlanetographicWest360 },
 	//{"Titan"      , NomenclatureItem::pcoPlanetographicWest360 },
-	{"Titania"    , NomenclatureItem::pcoPlanetocentricEast360 },
-	{"Triton"     , NomenclatureItem::pcoPlanetographicEast360 },
-	{"Umbriel"    , NomenclatureItem::pcoPlanetocentricEast360 },
-	{"Venus"      , NomenclatureItem::pcoPlanetocentricEast360 }};
+	{L1S("Titania")    , NomenclatureItem::pcoPlanetocentricEast360 },
+	{L1S("Triton")     , NomenclatureItem::pcoPlanetographicEast360 },
+	{L1S("Umbriel")    , NomenclatureItem::pcoPlanetocentricEast360 },
+	{L1S("Venus")      , NomenclatureItem::pcoPlanetocentricEast360 }};
 	return niPCOMap.value(planetName, NomenclatureItem::pcoPlanetographicWest360);
 }
 
