@@ -27,6 +27,7 @@
 #include "StelDialog.hpp"
 #include "StelCore.hpp"
 #include "StelObjectType.hpp"
+#include <QLoggingCategory>
 
 //! @class ObsListDialog
 //! Since V0.21.2, this class manages the ObservingLists, successor of the Bookmarks feature available since 0.15.
@@ -128,6 +129,9 @@
 
 class Ui_obsListDialogForm;
 
+Q_DECLARE_LOGGING_CATEGORY(ObsLists)
+
+
 class ObsListDialog : public StelDialog
 {
 	Q_OBJECT
@@ -142,9 +146,31 @@ public:
 
 	~ObsListDialog() override;
 
+	enum ObsListColumns {
+		ColumnUUID,          //! UUID of object
+		ColumnDesignation,   //! English name or catalog designation of object
+		ColumnNameI18n,      //! Localized name/nickname of object
+		ColumnType,          //! Localized detailed Type of the object
+		ColumnRa,            //! Right ascension of the object
+		ColumnDec,           //! Declination of the object
+		ColumnMagnitude,     //! Magnitude of the object
+		ColumnConstellation, //! Constellation in which the object is located
+		ColumnDate,          //! Date
+		ColumnLocation,      //! Location where the object is observed
+		ColumnLandscapeID,   //! LandscapeID linked to object observation
+		ColumnCount          //! Total number of columns
+	};
+	Q_ENUM(ObsListColumns)
+
+protected:
+	Ui_obsListDialogForm *ui;
+
+	//! Initialize the dialog widgets and connect the signals/slots.
+	void createDialogContent() override;
+
+private:
 	struct observingListItem
 	{
-	public:
 		QString designation;   //!< Relates to designation in the JSON file
 		QString name;          //!< Relates to name in the JSON file. This is the object's englishName
 		QString nameI18n;      //!< Relates to nameI18n in the JSON file. This is recreated from the actual object and current language during loading of the list. In the JSON file, it has purely add-on value.
@@ -197,36 +223,12 @@ public:
 		}
 	};
 
-	enum ObsListColumns {
-		ColumnUUID,          //! UUID of object
-		ColumnDesignation,   //! English name or catalog designation of object
-		ColumnNameI18n,      //! Localized name/nickname of object
-		ColumnType,          //! Localized detailed Type of the object
-		ColumnRa,            //! Right ascension of the object
-		ColumnDec,           //! Declination of the object
-		ColumnMagnitude,     //! Magnitude of the object
-		ColumnConstellation, //! Constellation in which the object is located
-		ColumnDate,          //! Date
-		ColumnLocation,      //! Location where the object is observed
-		ColumnLandscapeID,   //! LandscapeID linked to object observation
-		ColumnCount          //! Total number of columns
-	};
-	Q_ENUM(ObsListColumns)
-
-protected:
-	Ui_obsListDialogForm *ui;
-
-	//! Initialize the dialog widgets and connect the signals/slots.
-	void createDialogContent() override;
-
-private:
 	class StelCore *core;
 	class StelObjectMgr *objectMgr;
-	class LandscapeMgr *landscapeMgr;
 	class LabelMgr *labelMgr;
 
 	QStandardItemModel *itemModel;       //!< Data for the table display.
-	const QString observingListJsonPath; //!< Path to observingList.json file, set once in constructor.
+	QString observingListJsonPath;       //!< Path to observingList.json file, set once in constructor, but can be changed later.
 	const QString bookmarksJsonPath;     //!< Path to bookmarks.json, set once in constructor.
 
 	//! This QVariantMap represents the contents of the observingList.json file. Read ONCE at start. Contains 4 key/value pairs:
@@ -311,9 +313,6 @@ private:
 	//! @param newList activate creation mode. This is only relevant to aborts
 	void switchEditMode(bool enableEditMode, bool newList);
 
-	//! Save the object information into json file
-	void saveObservedObjectsInJsonFile();
-
 	//! Get the magnitude from selected object (or a dash if unavailable)
 	static QString getMagnitude(const QList<StelObjectP> &selectedObject, StelCore *core);
 
