@@ -55,7 +55,8 @@
 #include <QSettings>
 #include <QGuiApplication>
 
-void brightenImage(QImage &img, float factor)
+
+void StelButton::brightenImage(QImage &img, float factor)
 {
 	for (int y=0; y<img.height(); y++)
 		for (int x=0; x<img.width(); x++)
@@ -78,7 +79,6 @@ void brightenImage(QImage &img, float factor)
 		}
 }
 
-
 void StelButton::initCtor(const QPixmap& apixOn,
 						  const QPixmap& apixOff,
 						  const QPixmap& apixNoChange,
@@ -230,6 +230,12 @@ int StelButton::toggleChecked(int checked)
 	return checked;
 }
 
+double StelButton::buttonSizeRatio()
+{
+	const auto& app = StelApp::getInstance();
+	return app.screenFontSizeRatio() * app.getScreenButtonScale()/100;
+}
+
 void StelButton::hoverEnterEvent(QGraphicsSceneHoverEvent*)
 {
 	timeLine->setDirection(QTimeLine::Forward);
@@ -349,6 +355,18 @@ QRectF StelButton::boundingRect() const
 	return QRectF(0,0, getButtonPixmapWidth(), getButtonPixmapHeight());
 }
 
+
+int StelButton::getButtonPixmapWidth() const
+{
+	const double baseWidth = pixOn.width() / pixmapsScale * buttonSizeRatio();
+	return std::lround(baseWidth);
+}
+int StelButton::getButtonPixmapHeight() const
+{
+	const double baseHeight = pixOn.height() / pixmapsScale * buttonSizeRatio();
+	return std::lround(baseHeight);
+}
+
 void StelButton::paint(QPainter* painter, const QStyleOptionGraphicsItem*, QWidget*)
 {
 	/* QPixmap::scaled has much better quality than that scaling via QPainter::drawPixmap, so let's
@@ -364,11 +382,11 @@ void StelButton::paint(QPainter* painter, const QStyleOptionGraphicsItem*, QWidg
 	 *    rectangles.
 	 *    Our keeping QPixmap alive instead of deleting it on return from this function prevents this.
 	 */
-	const double ratio = QOpenGLContext::currentContext()->screen()->devicePixelRatio();
+	const double ratio = StelApp::getInstance().getDevicePixelsPerPixel();
 	if(scaledCurrentPixmap.isNull() || ratio != scaledCurrentPixmap.devicePixelRatioF())
 	{
-		const auto scale = ratio / pixmapsScale;
-		scaledCurrentPixmap = pixmap().scaled(pixOn.size()*scale, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
+		const auto size = boundingRect().size() * ratio;
+		scaledCurrentPixmap = pixmap().scaled(size.toSize(), Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
 		scaledCurrentPixmap.setDevicePixelRatio(ratio);
 	}
 	// Align the pixmap to pixel grid, otherwise we'll get artifacts at some scaling factors.
@@ -388,6 +406,10 @@ LeftStelBar::LeftStelBar(QGraphicsItem* parent)
 
 	setFontSizeFromApp(StelApp::getInstance().getScreenFontSize());
 	connect(&StelApp::getInstance(), &StelApp::screenFontSizeChanged, this, &LeftStelBar::setFontSizeFromApp);
+	connect(&StelApp::getInstance(), &StelApp::screenButtonScaleChanged, this,
+	        [this]{const int size = StelApp::getInstance().getScreenFontSize();
+	               setFontSizeFromApp(size); /* and repeat to apply all the geometry changes */
+	               setFontSizeFromApp(size);});
 	connect(&StelApp::getInstance(), &StelApp::fontChanged, this, &LeftStelBar::setFont);
 }
 
@@ -402,16 +424,28 @@ void LeftStelBar::addButton(StelButton* button)
 	if (QGraphicsItem::childItems().size()!=0)
 	{
 		const QRectF& r = childrenBoundingRect();
-		posY += r.bottom()-1;
+		posY += r.bottom();
 	}
 	button->setParentItem(this);
 	button->setFocusOnSky(false);
 	//button->prepareGeometryChange(); // could possibly be removed when qt 4.6 become stable
-	button->setPos(0., qRound(posY+10.5));
+	button->setPos(0., qRound(posY + 9.5 * StelButton::buttonSizeRatio()));
 
 	connect(button, SIGNAL(hoverChanged(bool)), this, SLOT(buttonHoverChanged(bool)));
 }
 
+void LeftStelBar::updateButtonPositions()
+{
+	double posY = 0;
+	for (const auto button : childItems())
+	{
+		if (const auto b = dynamic_cast<StelButton*>(button))
+			b->animValueChanged(0.); // update button pixmap
+		button->setPos(0., posY);
+		posY += std::round(button->boundingRect().height() + 9.5 * StelButton::buttonSizeRatio());
+	}
+}
+
 void LeftStelBar::paint(QPainter*, const QStyleOptionGraphicsItem*, QWidget*)
 {
 }
@@ -476,6 +510,7 @@ void LeftStelBar::setColor(const QColor& c)
 //! connect from StelApp to resize fonts on the fly.
 void LeftStelBar::setFontSizeFromApp(int size)
 {
+	prepareGeometryChange();
 	// Font size was developed based on base font size 13, i.e. 12
 	int screenFontSize = size-1;
 	QFont font=QGuiApplication::font();
@@ -487,7 +522,10 @@ void LeftStelBar::setFontSizeFromApp(int size)
 		// to avoid crash
 		SkyGui* skyGui=gui->getSkyGui();
 		if (skyGui)
+		{
 			skyGui->updateBarsPos();
+			updateButtonPositions();
+		}
 	}
 }
 
@@ -534,6 +572,10 @@ BottomStelBar::BottomStelBar(QGraphicsItem* parent,
 
 	setFontSizeFromApp(StelApp::getInstance().getScreenFontSize());
 	connect(&StelApp::getInstance(), &StelApp::screenFontSizeChanged, this, [=](int fontsize){setFontSizeFromApp(fontsize); setFontSizeFromApp(fontsize);}); // We must call that twice to force all geom. updates
+	connect(&StelApp::getInstance(), &StelApp::screenButtonScaleChanged, this,
+	        [this]{const int size = StelApp::getInstance().getScreenFontSize();
+	               setFontSizeFromApp(size); /* and repeat to apply all the geometry changes */
+	               setFontSizeFromApp(size);});
 	connect(&StelApp::getInstance(), &StelApp::fontChanged, this, &BottomStelBar::setFont);
 	connect(StelApp::getInstance().getCore(), &StelCore::flagUseTopocentricCoordinatesChanged, this, [=](bool){updateText(false, true);});
 
@@ -581,6 +623,7 @@ void BottomStelBar::setFont(const QFont &cfont)
 	location->setFont(font);
 	fov->setFont(font);
 	fps->setFont(font);
+	helpLabel->setFont(font);
 	StelGui* gui = dynamic_cast<StelGui*>(StelApp::getInstance().getGui());
 	if (gui)
 	{
