@@ -21,6 +21,7 @@
 
 #include "ViewDialog.hpp"
 #include "ui_viewDialog.h"
+#include <QMessageBox>
 #include "AddRemoveLandscapesDialog.hpp"
 #include "AtmosphereDialog.hpp"
 #include "SkylightDialog.hpp"
@@ -31,6 +32,7 @@
 #include "StelApp.hpp"
 #include "StelCore.hpp"
 #include "StelModule.hpp"
+#include "StelMainView.hpp"
 #include "LandscapeMgr.hpp"
 #include "StelSkyCultureMgr.hpp"
 #include "ConstellationMgr.hpp"
@@ -49,6 +51,7 @@
 #include "StelPropertyMgr.hpp"
 #include "StelHips.hpp"
 #include "StelMovementMgr.hpp"
+#include "StelSpeechMgr.hpp"
 
 #include <QDebug>
 #include <QFrame>
@@ -76,6 +79,27 @@ struct Page
 	};
 };
 
+struct HipsRole
+{
+	enum
+	{
+		URL = Qt::UserRole,
+		PlanetEnglishName,
+		ItemType,
+		SurveyType,
+	};
+};
+
+struct HipsItemType
+{
+	enum
+	{
+		Survey, // The HiPS itself
+		Planet, // The item representing a planet and containing groups of surveys
+		Group,  // Group of planetary surveys: albedo+normals+horizons
+	};
+};
+
 ViewDialog::ViewDialog(QObject* parent) : StelDialog("View", parent)
 	, addRemoveLandscapesDialog(nullptr)
 	, atmosphereDialog(nullptr)
@@ -116,15 +140,22 @@ void ViewDialog::retranslate()
 {
 	if (dialog)
 	{
+		static StelSkyCultureMgr *scMgr = GETSTELMODULE(StelSkyCultureMgr);
+
 		ui->retranslateUi(dialog);
 		updateZhrDescription(StelApp::getInstance().getModule("SporadicMeteorMgr")->property("zhr").toInt());
 		populateLists();
 		populateToolTips();
 		populatePlanetMagnitudeAlgorithmsList();
 		populatePlanetMagnitudeAlgorithmDescription();
+		populateCulturalCombo(ui->zodiacLabelComboBox, scMgr->getZodiacLabelStyle());
+		populateCulturalCombo(ui->lunarSystemLabelComboBox, scMgr->getLunarSystemLabelStyle());
 		ui->lightPollutionWidget->retranslate();
+
 		populateHipsGroups();
+		clearHips();
 		updateHips();
+
 		//Hack to shrink the tabs to optimal size after language change
 		//by causing the list items to be laid out again.
 		updateTabBarListWidgetWidth();
@@ -167,7 +198,7 @@ void ViewDialog::createDialogContent()
 	connect(ui->stackListWidget, SIGNAL(currentItemChanged(QListWidgetItem *, QListWidgetItem *)), this, SLOT(changePage(QListWidgetItem *, QListWidgetItem*)));
 	// Kinetic scrolling
 	kineticScrollingList << ui->projectionListWidget << ui->culturesListWidget << ui->skyCultureTextBrowser << ui->landscapesListWidget
-			     << ui->landscapeTextBrowser << ui->surveysListWidget << ui->surveysTextBrowser;
+			     << ui->landscapeTextBrowser << ui->surveysTreeWidget << ui->surveysTextBrowser;
 	StelGui* gui= dynamic_cast<StelGui*>(StelApp::getInstance().getGui());
 	if (gui)
 	{
@@ -451,6 +482,7 @@ void ViewDialog::createDialogContent()
 	// The thickness of lines
 	connectIntProperty(ui->lineThicknessSpinBox,                "GridLinesMgr.lineThickness");
 	connectIntProperty(ui->partThicknessSpinBox,                "GridLinesMgr.partThickness");
+	connectIntProperty(ui->pointSizeSpinBox,	            "GridLinesMgr.pointSize");
 	connectBoolProperty(ui->equatorPartsCheckBox,               "GridLinesMgr.equatorPartsDisplayed");
 	connectBoolProperty(ui->equatorJ2000PartsCheckBox,          "GridLinesMgr.equatorJ2000PartsDisplayed");
 	connectBoolProperty(ui->fixedEquatorPartsCheckBox,          "GridLinesMgr.fixedEquatorPartsDisplayed");
@@ -566,6 +598,7 @@ void ViewDialog::createDialogContent()
 	connect(ui->infoLabelTransliterationCheckBox  , &QCheckBox::clicked, this, &ViewDialog::updateSkyCultureInfoStyleFromCheckboxes);
 	connect(ui->infoLabelTranslationCheckBox      , &QCheckBox::clicked, this, &ViewDialog::updateSkyCultureInfoStyleFromCheckboxes);
 	connect(ui->infoLabelIPACheckBox              , &QCheckBox::clicked, this, &ViewDialog::updateSkyCultureInfoStyleFromCheckboxes);
+	connect(ui->infoLabelBynameCheckBox           , &QCheckBox::clicked, this, &ViewDialog::updateSkyCultureInfoStyleFromCheckboxes);
 	connect(ui->infoLabelModernCheckBox           , &QCheckBox::clicked, this, &ViewDialog::updateSkyCultureInfoStyleFromCheckboxes);
 
 	connect(ui->screenLabelNativeCheckBox         , &QCheckBox::clicked, this, &ViewDialog::updateSkyCultureScreenStyleFromCheckboxes);
@@ -573,6 +606,7 @@ void ViewDialog::createDialogContent()
 	connect(ui->screenLabelTransliterationCheckBox, &QCheckBox::clicked, this, &ViewDialog::updateSkyCultureScreenStyleFromCheckboxes);
 	connect(ui->screenLabelTranslationCheckBox    , &QCheckBox::clicked, this, &ViewDialog::updateSkyCultureScreenStyleFromCheckboxes);
 	connect(ui->screenLabelIPACheckBox            , &QCheckBox::clicked, this, &ViewDialog::updateSkyCultureScreenStyleFromCheckboxes);
+	connect(ui->screenLabelBynameCheckBox         , &QCheckBox::clicked, this, &ViewDialog::updateSkyCultureScreenStyleFromCheckboxes);
 	connect(ui->screenLabelModernCheckBox         , &QCheckBox::clicked, this, &ViewDialog::updateSkyCultureScreenStyleFromCheckboxes);
 
 	connectBoolProperty(ui->abbreviatedNamesCheckBox,               "StelSkyCultureMgr.flagUseAbbreviatedNames");
@@ -628,14 +662,16 @@ void ViewDialog::createDialogContent()
 
 	connectBoolProperty(ui->zodiacCheckBox, "ConstellationMgr.zodiacDisplayed");
 	connectBoolProperty(ui->lunarSystemCheckBox, "ConstellationMgr.lunarSystemDisplayed");
-	ui->zodiacColorButton->setup("ConstellationMgr.zodiacColor", "color/sc_zodiac_color");
-	ui->lunarSystemColorButton->setup("ConstellationMgr.lunarSystemColor", "color/sc_lunarsystem_color");
+	ui->zodiacColorButton->setup("ConstellationMgr.zodiacColor", "color/skyculture_zodiac_color");
+	ui->lunarSystemColorButton->setup("ConstellationMgr.lunarSystemColor", "color/skyculture_lunarsystem_color");
 
 	connectIntProperty(ui->zodiacThicknessSpinBox,	                "ConstellationMgr.zodiacThickness");
 	connectIntProperty(ui->lunarSystemThicknessSpinBox,	        "ConstellationMgr.lunarSystemThickness");
 	connectDoubleProperty(ui->zodiacFadeDurationDoubleSpinBox,      "ConstellationMgr.zodiacFadeDuration");
 	connectDoubleProperty(ui->lunarSystemFadeDurationDoubleSpinBox, "ConstellationMgr.lunarSystemFadeDuration");
 
+	connect(ui->zodiacLabelComboBox,      SIGNAL(currentIndexChanged(int)), this, SLOT(setZodiacLabelStyle(int)));
+	connect(ui->lunarSystemLabelComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(setLunarSystemLabelStyle(int)));
 
 	// Font selection
 	connectIntProperty(ui->constellationsFontSizeSpinBox, "ConstellationMgr.fontSize");
@@ -655,8 +691,8 @@ void ViewDialog::createDialogContent()
 
 	connect(ui->surveyTypeComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(updateHips()));
 	connect(ui->stackListWidget, SIGNAL(currentItemChanged(QListWidgetItem *, QListWidgetItem *)), this, SLOT(updateHips()));
-	connect(ui->surveysListWidget, SIGNAL(currentRowChanged(int)), this, SLOT(updateHips()), Qt::QueuedConnection);
-	connect(ui->surveysListWidget, SIGNAL(itemChanged(QListWidgetItem*)), this, SLOT(hipsListItemChanged(QListWidgetItem*)));
+	connect(ui->surveysTreeWidget, &QTreeWidget::currentItemChanged, this, &ViewDialog::updateHipsText, Qt::QueuedConnection);
+	connect(ui->surveysTreeWidget, &QTreeWidget::itemChanged, this, &ViewDialog::hipsListItemChanged);
 	connect(ui->surveysFilter, &QLineEdit::textChanged, this, &ViewDialog::filterSurveys);
 	updateHips();
 
@@ -668,6 +704,40 @@ void ViewDialog::createDialogContent()
 		ui->landscapeTextBrowser->document()->setDefaultStyleSheet(style);
 		ui->skyCultureTextBrowser->document()->setDefaultStyleSheet(style);
 	});
+
+	// Connect narration buttons. We might need to prepare the texts, though.
+	if (GETSTELMODULE(StelSpeechMgr)->enabled())
+	{
+		connect(ui->pushButtonLandscapes_say, &QPushButton::clicked, this, [this](){
+			static LandscapeMgr *lmgr=GETSTELMODULE(LandscapeMgr);
+
+			QString pureContent=lmgr->getDescription();
+			static const QRegularExpression htmlbegin("<.*>");
+			static const QRegularExpression htmlend("</.*>");
+			static const QRegularExpression htmlendH("</[Hh][1-4]>");
+			static const QRegularExpression html1("<.*/>");
+			QString stripped=pureContent.replace(htmlendH, ". . . ").remove(html1).remove(htmlend).remove(htmlbegin);
+
+			GETSTELMODULE(StelSpeechMgr)->say(stripped);});
+		connect(ui->pushButtonLandscapes_stop, &QPushButton::clicked, this, [this](){
+			GETSTELMODULE(StelSpeechMgr)->stop();});
+		connect(ui->pushButtonSkyculture_say, &QPushButton::clicked, this, [this](){
+			StelApp& app = StelApp::getInstance();
+			QString md = app.getSkyCultureMgr().getCurrentSkyCultureNarration();
+			qDebug() << "MD as received: " << md;
+
+			GETSTELMODULE(StelSpeechMgr)->say(md);
+		});
+		connect(ui->pushButtonSkyculture_stop, &QPushButton::clicked, this, [this](){
+			GETSTELMODULE(StelSpeechMgr)->stop();});
+	}
+	else
+	{
+		const auto wList = QList<QWidget*>({ui->pushButtonLandscapes_say, ui->pushButtonLandscapes_stop,
+						    ui->pushButtonSkyculture_say, ui->pushButtonSkyculture_stop});
+		for (auto w: wList)
+			w->hide();
+	}
 }
 
 bool ViewDialog::eventFilter(QObject* object, QEvent* event)
@@ -725,44 +795,92 @@ void ViewDialog::populateNomenclatureControls(bool flag)
 // Heuristic function to decide in which group to put a survey.
 static QString getHipsType(const HipsSurveyP hips)
 {
-	QJsonObject properties = hips->property("properties").toJsonObject();
 	if (!hips->isPlanetarySurvey())
 		return "dss";
-	if (properties["type"].toString() == "planet") // TODO: switch to use hips->isPlanetarySurvey() and multiple surveys for Solar system bodies
+	const auto type = hips->getType();
+	if (type == "planet" || type == "planet-normal" || type == "planet-horizon")
 		return "sol";
 	return "other";
 }
 
+void ViewDialog::updateHipsText()
+{
+	const auto currentItem = ui->surveysTreeWidget->currentItem();
+	if (!currentItem)
+	{
+		ui->surveysTextBrowser->setText("");
+		return;
+	}
+
+	const auto hipsmgr = qobject_cast<HipsMgr*>(StelApp::getInstance().getModule("HipsMgr"));
+	const auto url = currentItem->data(0, HipsRole::URL).toString();
+	const auto hips = hipsmgr->getSurveyByUrl(url);
+	if (!hips)
+	{
+		ui->surveysTextBrowser->setText("");
+		return;
+	}
+	QJsonObject props = hips->property("properties").toJsonObject();
+	QString html = QString("<h1>%1</h1>\n").arg(props["obs_title"].toString());
+	if (props.contains("obs_copyright") && props.contains("obs_copyright_url"))
+	{
+		html += QString("<p>Copyright <a href='%2'>%1</a></p>\n")
+				.arg(props["obs_copyright"].toString(), props["obs_copyright_url"].toString());
+	}
+	html += QString("<p>%1</p>\n").arg(props["obs_description"].toString());
+	html += "<h2>" + q_("properties") + "</h2>\n<ul>\n";
+	for (auto iter = props.constBegin(); iter != props.constEnd(); iter++)
+	{
+		html += QString("<li><b>%1</b> %2</li>\n").arg(iter.key(), iter.value().toString());
+	}
+	html += "</ul>\n";
+	const auto gui = dynamic_cast<StelGui*>(StelApp::getInstance().getGui());
+	if (gui)
+		ui->surveysTextBrowser->document()->setDefaultStyleSheet(QString(gui->getStelStyle().htmlStyleSheet));
+	ui->surveysTextBrowser->setHtml(html);
+}
+
+void ViewDialog::clearHips()
+{
+	ui->surveysTreeWidget->clear();
+	planetarySurveys.clear();
+	surveysInTheList.clear();
+	selectedSurveyType.clear();
+}
+
 void ViewDialog::updateHips()
 {
 	if (!ui->page_surveys->isVisible()) return;
-	StelGui* gui = dynamic_cast<StelGui*>(StelApp::getInstance().getGui());
-	StelModule *hipsmgr = StelApp::getInstance().getModule("HipsMgr");
+	const auto hipsmgr = qobject_cast<HipsMgr*>(StelApp::getInstance().getModule("HipsMgr"));
 	QMetaObject::invokeMethod(hipsmgr, "loadSources");
 
 	QComboBox* typeComboBox = ui->surveyTypeComboBox;
-	QVariant selectedType = typeComboBox->itemData(typeComboBox->currentIndex());
+	auto selectedType = typeComboBox->itemData(typeComboBox->currentIndex()).toString();
 	if (selectedType.isNull())
 		selectedType = "dss";
 
 	// Update survey list.
-	QListWidget* l = ui->surveysListWidget;
+	auto*const l = ui->surveysTreeWidget;
 
 	if (!hipsmgr->property("loaded").toBool())
 	{
-		l->clear();
-		new QListWidgetItem(q_("Loading..."), l);
+		clearHips();
+		new QTreeWidgetItem(l, {q_("Loading...")});
 		return;
 	}
 
-	QString currentSurvey = l->currentItem() ? l->currentItem()->data(Qt::UserRole).toString() : "";
-	QListWidgetItem* currentItem = nullptr;
-	HipsSurveyP currentHips;
-
 	l->blockSignals(true);
-	l->clear();
+	if (selectedSurveyType != selectedType)
+	{
+		clearHips();
+		selectedSurveyType = selectedType;
+	}
 	const QList<HipsSurveyP> hipslist = hipsmgr->property("surveys").value<QList<HipsSurveyP>>();
 
+	const bool selectedIsPlanetary = selectedType == "sol";
+	l->setRootIsDecorated(selectedIsPlanetary);
+
+	const auto& solarSys = GETSTELMODULE(SolarSystem);
 	for (auto &hips: hipslist)
 	{
 		if (getHipsType(hips) != selectedType)
@@ -770,49 +888,112 @@ void ViewDialog::updateHips()
 		QString url = hips->property("url").toString();
 		QJsonObject properties = hips->property("properties").toJsonObject();
 		QString title = properties["obs_title"].toString();
-		if (title.isEmpty())
+		if (title.isEmpty() || url.isEmpty())
 			continue;
-		QListWidgetItem* item = new QListWidgetItem(title, l);
-		item->setFlags(item->flags() | Qt::ItemIsUserCheckable);
-		item->setCheckState(hips->property("visible").toBool() ? Qt::Checked : Qt::Unchecked);
-		item->setData(Qt::UserRole, url);
-		if (url == currentSurvey)
-		{
-			currentItem = item;
-			currentHips = hips;
-		}
-		disconnect(hips.data(), nullptr, this, nullptr);
-		connect(hips.data(), SIGNAL(statusChanged()), this, SLOT(updateHips()));
-	}
-	l->sortItems(Qt::AscendingOrder);
-	l->setCurrentItem(currentItem);
-	l->scrollToItem(currentItem);
-	l->blockSignals(false);
 
-	if (!currentHips)
-	{
-		ui->surveysTextBrowser->setText("");
-	}
-	else
-	{
-		QJsonObject props = currentHips->property("properties").toJsonObject();
-		QString html = QString("<h1>%1</h1>\n").arg(props["obs_title"].toString());
-		if (props.contains("obs_copyright") && props.contains("obs_copyright_url"))
+		// Don't add the survey if it's already present
+		const auto surveyItemIt = surveysInTheList.find(url);
+		if (surveyItemIt != surveysInTheList.end())
+			continue;
+
+		QTreeWidgetItem* surveyItem = nullptr;
+		if (selectedIsPlanetary)
 		{
-			html += QString("<p>Copyright <a href='%2'>%1</a></p>\n")
-					.arg(props["obs_copyright"].toString(), props["obs_copyright_url"].toString());
+			const auto& frame = hips->getFrame();
+			const auto& englishName = hips->frameToPlanetName(frame);
+			const auto& group = hips->getGroup();
+			auto& planetData = planetarySurveys[englishName];
+			if(!planetData.planetItem)
+			{
+				const auto& planet = solarSys->searchByEnglishName(englishName);
+				if (!planet)
+				{
+					qWarning().nospace() << "Found a planetary survey with unknown frame: "
+					                     << frame << ". Skipping it.";
+					continue;
+				}
+				planetData.planetItem = new QTreeWidgetItem(l, {planet->getNameI18n()});
+				planetData.planetItem->setData(0, HipsRole::ItemType, HipsItemType::Planet);
+				planetData.planetItem->setData(0, HipsRole::PlanetEnglishName, englishName);
+			}
+			QTreeWidgetItem*& groupItem = planetData.groupsMap[group];
+			if (!groupItem)
+			{
+				groupItem = new QTreeWidgetItem(planetData.planetItem, {group});
+				groupItem->setData(0, HipsRole::ItemType, HipsItemType::Group);
+				groupItem->setFlags(groupItem->flags() | Qt::ItemIsUserCheckable);
+				groupItem->setCheckState(0, hips->property("visible").toBool() ? Qt::Checked : Qt::Unchecked);
+			}
+			static const QHash<QString, QString> typeNames = {
+				{L1S("planet"),         q_("Albedo")},
+				{L1S("planet-normal"),  q_("Normal map")},
+				{L1S("planet-horizon"), q_("Horizon map")},
+			};
+			const auto type = hips->getType();
+			QString typeName = type;
+			if (const auto it = typeNames.find(type); it != typeNames.end())
+				typeName = it.value();
+
+			// Set the first survey of each type as checked by default
+			auto checkState = Qt::Checked;
+			const bool newHipsVisible = hips->property("visible").toBool();
+			if (newHipsVisible)
+			{
+				// The group is also enabled if the survey being added is visible
+				groupItem->setCheckState(0, Qt::Checked);
+			}
+			for (int n = 0; n < groupItem->childCount(); ++n)
+			{
+				const auto oldHipsItem = groupItem->child(n);
+				Q_ASSERT(oldHipsItem->data(0, HipsRole::ItemType).toInt() == HipsItemType::Survey);
+
+				if (oldHipsItem->data(0, HipsRole::SurveyType).toString() != type)
+					continue;
+				bool oldHipsItemChecked = oldHipsItem->checkState(0) == Qt::Checked;
+				if (newHipsVisible && oldHipsItemChecked)
+				{
+					const auto url = oldHipsItem->data(0, HipsRole::URL).toString();
+					const auto oldHips = hipsmgr->getSurveyByUrl(url);
+					Q_ASSERT(oldHips);
+					if (oldHips && !oldHips->property("visible").toBool())
+					{
+						checkState = Qt::Checked;
+						oldHipsItem->setCheckState(0, Qt::Unchecked);
+						oldHipsItemChecked = false;
+					}
+				}
+				if (!newHipsVisible && oldHipsItemChecked)
+				{
+					// A checked survey already exists, don't check the new one
+					checkState = Qt::Unchecked;
+					break;
+				}
+			}
+
+			surveyItem = new QTreeWidgetItem(groupItem, {title, typeName});
+			surveyItem->setFlags(surveyItem->flags() | Qt::ItemIsUserCheckable);
+			surveyItem->setCheckState(0, checkState);
 		}
-		html += QString("<p>%1</p>\n").arg(props["obs_description"].toString());
-		html += "<h2>" + q_("properties") + "</h2>\n<ul>\n";
-		for (auto iter = props.constBegin(); iter != props.constEnd(); iter++)
+		else
 		{
-			html += QString("<li><b>%1</b> %2</li>\n").arg(iter.key(), iter.value().toString());
+			surveyItem = new QTreeWidgetItem(l, {title});
+			surveyItem->setFlags(surveyItem->flags() | Qt::ItemIsUserCheckable);
+			surveyItem->setCheckState(0, hips->property("visible").toBool() ? Qt::Checked
+			                                                                : Qt::Unchecked);
 		}
-		html += "</ul>\n";
-		if (gui)
-			ui->surveysTextBrowser->document()->setDefaultStyleSheet(QString(gui->getStelStyle().htmlStyleSheet));
-		ui->surveysTextBrowser->setHtml(html);
+
+		surveysInTheList[url] = surveyItem;
+		surveyItem->setData(0, HipsRole::ItemType, HipsItemType::Survey);
+		surveyItem->setData(0, HipsRole::URL, url);
+		surveyItem->setData(0, HipsRole::SurveyType, hips->getType());
+		disconnect(hips.data(), nullptr, this, nullptr);
+		connect(hips.data(), &HipsSurvey::statusChanged, this, &ViewDialog::updateHipsText);
 	}
+	l->sortItems(0, Qt::AscendingOrder);
+	if (const auto currentItem = l->currentItem())
+		l->scrollToItem(currentItem);
+
+	l->blockSignals(false);
 	filterSurveys();
 }
 
@@ -857,35 +1038,131 @@ void ViewDialog::toggleHipsDialog()
 void ViewDialog::filterSurveys()
 {
 	const QString pattern = ui->surveysFilter->text().simplified();
-	const auto& list = *ui->surveysListWidget;
-	for (int row = 0; row < list.count(); ++row)
+	const auto& list = *ui->surveysTreeWidget;
+	for (int row = 0; row < list.topLevelItemCount(); ++row)
 	{
-		auto& item = *list.item(row);
-		const QString text = item.text().simplified();
+		auto& item = *list.topLevelItem(row);
+		const QString text = item.text(0).simplified();
 		const bool show = pattern.isEmpty() || text.contains(pattern, Qt::CaseInsensitive);
 		item.setHidden(!show);
 	}
 }
 
-void ViewDialog::hipsListItemChanged(QListWidgetItem* item)
+void ViewDialog::hipsListItemChanged(QTreeWidgetItem* item)
 {
-	QListWidget* l = item->listWidget();
+	auto*const l = item->treeWidget();
 	l->blockSignals(true);
-	StelModule *hipsmgr = StelApp::getInstance().getModule("HipsMgr");
-	QString url = item->data(Qt::UserRole).toString();
-	HipsSurveyP hips;
-	QMetaObject::invokeMethod(hipsmgr, "getSurveyByUrl", Qt::DirectConnection,
-			Q_RETURN_ARG(HipsSurveyP, hips), Q_ARG(QString, url));
-	Q_ASSERT(hips);
-	if (item->checkState() == Qt::Checked)
+	const auto hipsmgr = qobject_cast<HipsMgr*>(StelApp::getInstance().getModule("HipsMgr"));
+
+	switch (item->data(0, HipsRole::ItemType).toInt())
 	{
-		l->setCurrentItem(item);
-		hips->setProperty("visible", true);
-	}
-	else
+	case HipsItemType::Survey:
 	{
-		hips->setProperty("visible", false);
+		const auto url = item->data(0, HipsRole::URL).toString();
+		if (const auto group = item->parent())
+		{
+			Q_ASSERT(group->data(0, HipsRole::ItemType).toInt() == HipsItemType::Group);
+			for (int n = 0; n < group->childCount(); ++n)
+			{
+				const auto surveyItem = group->child(n);
+				Q_ASSERT(surveyItem->data(0, HipsRole::ItemType).toInt() == HipsItemType::Survey);
+				if (surveyItem == item) continue;
+				// Only consider surveys of the same type
+				if (surveyItem->data(0, HipsRole::SurveyType) != item->data(0, HipsRole::SurveyType))
+					continue;
+				if (surveyItem->checkState(0) == Qt::Checked)
+				{
+					surveyItem->setCheckState(0, Qt::Unchecked);
+				}
+			}
+			hipsListItemChanged(group);
+		}
+		else
+		{
+			const auto hips = hipsmgr->getSurveyByUrl(url);
+			Q_ASSERT(hips);
+			if (item->checkState(0) == Qt::Checked)
+			{
+				l->setCurrentItem(item);
+				hips->setProperty("visible", true);
+			}
+			else
+			{
+				hips->setProperty("visible", false);
+			}
+		}
+		break;
 	}
+	case HipsItemType::Group:
+	{
+		// First, uncheck all the sibling groups except the one we're enabling
+		if (item->checkState(0) == Qt::Checked)
+		{
+			const auto planetItem = item->parent();
+			Q_ASSERT(planetItem);
+			Q_ASSERT(planetItem->data(0, HipsRole::ItemType).toInt() == HipsItemType::Planet);
+			for (int n = 0; n < planetItem->childCount(); ++n)
+			{
+				const auto groupItem = planetItem->child(n);
+				Q_ASSERT(groupItem->data(0, HipsRole::ItemType).toInt() == HipsItemType::Group);
+				if (groupItem == item) continue;
+				if (groupItem->checkState(0) == Qt::Checked)
+				{
+					groupItem->setCheckState(0, Qt::Unchecked);
+					hipsListItemChanged(groupItem);
+				}
+			}
+		}
+
+		// Now configure the survey chosen
+		HipsSurveyP colors;
+		HipsSurveyP normals;
+		HipsSurveyP horizons;
+		for (int n = 0; n < item->childCount(); ++n)
+		{
+			const auto child = item->child(n);
+			const auto url = child->data(0, HipsRole::URL).toString();
+			const auto hips = hipsmgr->getSurveyByUrl(url);
+			Q_ASSERT(hips);
+			const auto type = hips->getType();
+			if (child->checkState(0) != Qt::Checked)
+			{
+				if (type == L1S("planet"))
+					hips->setProperty("visible", false);
+				continue;
+			}
+			if (type == L1S("planet"))
+				colors = hips;
+			else if (type == L1S("planet-normal"))
+				normals = hips;
+			else if (type == L1S("planet-horizon"))
+				horizons = hips;
+		}
+		if (item->checkState(0) == Qt::Checked)
+		{
+			if (!colors)
+			{
+				QMessageBox::critical(&StelMainView::getInstance(), q_("No albedo map"),
+				                      q_("This group of surveys doesn't have an albedo "
+				                         "map. Can't display it."));
+				return;
+			}
+			colors->setProperty("visible", true);
+			const auto solarSys = qobject_cast<SolarSystem*>(StelApp::getInstance().getModule("SolarSystem"));
+			solarSys->enableSurvey(colors, normals, horizons);
+		}
+		else
+		{
+			if (colors) colors->setProperty("visible", false);
+		}
+		break;
+	}
+	case HipsItemType::Planet:
+	{
+		break;
+	}
+	}
+
 	l->blockSignals(false);
 }
 
@@ -1190,6 +1467,8 @@ void ViewDialog::configureSkyCultureCheckboxes()
 	static StelSkyCultureMgr *scMgr     = GETSTELMODULE(StelSkyCultureMgr);
 	StelObject::CulturalDisplayStyle infoStyle   = scMgr->getInfoLabelStyle();
 	StelObject::CulturalDisplayStyle screenStyle = scMgr->getScreenLabelStyle();
+	StelObject::CulturalDisplayStyle zodiacStyle = scMgr->getZodiacLabelStyle();
+	StelObject::CulturalDisplayStyle lunarStyle  = scMgr->getLunarSystemLabelStyle();
 	static ConstellationMgr *cMgr       = GETSTELMODULE(ConstellationMgr);
 	const bool hasZodiac=cMgr->hasZodiac();
 	const bool hasLunarSystem=cMgr->hasLunarSystem();
@@ -1199,19 +1478,26 @@ void ViewDialog::configureSkyCultureCheckboxes()
 	ui->infoLabelTransliterationCheckBox  ->setChecked(int(infoStyle)   & int(StelObject::CulturalDisplayStyle::Translit));
 	ui->infoLabelTranslationCheckBox      ->setChecked(int(infoStyle)   & int(StelObject::CulturalDisplayStyle::Translated));
 	ui->infoLabelIPACheckBox              ->setChecked(int(infoStyle)   & int(StelObject::CulturalDisplayStyle::IPA));
+	ui->infoLabelBynameCheckBox           ->setChecked(int(infoStyle)   & int(StelObject::CulturalDisplayStyle::Byname));
 	ui->infoLabelModernCheckBox           ->setChecked(int(infoStyle)   & int(StelObject::CulturalDisplayStyle::Modern));
 	ui->screenLabelNativeCheckBox         ->setChecked(int(screenStyle) & int(StelObject::CulturalDisplayStyle::Native));
 	ui->screenLabelPronounceCheckBox      ->setChecked(int(screenStyle) & int(StelObject::CulturalDisplayStyle::Pronounce));
 	ui->screenLabelTransliterationCheckBox->setChecked(int(screenStyle) & int(StelObject::CulturalDisplayStyle::Translit));
 	ui->screenLabelTranslationCheckBox    ->setChecked(int(screenStyle) & int(StelObject::CulturalDisplayStyle::Translated));
 	ui->screenLabelIPACheckBox            ->setChecked(int(screenStyle) & int(StelObject::CulturalDisplayStyle::IPA));
+	ui->screenLabelBynameCheckBox         ->setChecked(int(screenStyle) & int(StelObject::CulturalDisplayStyle::Byname));
 	ui->screenLabelModernCheckBox         ->setChecked(int(screenStyle) & int(StelObject::CulturalDisplayStyle::Modern));
 
+	populateCulturalCombo(ui->zodiacLabelComboBox, zodiacStyle);
+	populateCulturalCombo(ui->lunarSystemLabelComboBox, lunarStyle);
+
 	ui->zodiacCheckBox->setEnabled(hasZodiac);
+	ui->zodiacLabelComboBox->setEnabled(hasZodiac);
 	ui->zodiacColorButton->setEnabled(hasZodiac);
 	ui->zodiacFadeDurationDoubleSpinBox->setEnabled(hasZodiac);
 	ui->zodiacThicknessSpinBox->setEnabled(hasZodiac);
 	ui->lunarSystemCheckBox->setEnabled(hasLunarSystem);
+	ui->lunarSystemLabelComboBox->setEnabled(hasLunarSystem);
 	ui->lunarSystemColorButton->setEnabled(hasLunarSystem);
 	ui->lunarSystemFadeDurationDoubleSpinBox->setEnabled(hasLunarSystem);
 	ui->lunarSystemThicknessSpinBox->setEnabled(hasLunarSystem);
@@ -1222,6 +1508,7 @@ void ViewDialog::updateSkyCultureInfoStyleFromCheckboxes()
 	static StelSkyCultureMgr *scMgr       = GETSTELMODULE(StelSkyCultureMgr);
 
 	scMgr->setInfoLabelStyle(static_cast<StelObject::CulturalDisplayStyle>(
+				int(ui->infoLabelBynameCheckBox         ->isChecked()) << 6 |
 				int(ui->infoLabelNativeCheckBox         ->isChecked()) << 5 |
 				int(ui->infoLabelPronounceCheckBox      ->isChecked()) << 4 |
 				int(ui->infoLabelTransliterationCheckBox->isChecked()) << 3 |
@@ -1236,6 +1523,7 @@ void ViewDialog::updateSkyCultureScreenStyleFromCheckboxes()
 	static StelSkyCultureMgr *scMgr       = GETSTELMODULE(StelSkyCultureMgr);
 
 	scMgr->setScreenLabelStyle(static_cast<StelObject::CulturalDisplayStyle>(
+				int(ui->screenLabelBynameCheckBox         ->isChecked()) << 6 |
 				int(ui->screenLabelNativeCheckBox         ->isChecked()) << 5 |
 				int(ui->screenLabelPronounceCheckBox      ->isChecked()) << 4 |
 				int(ui->screenLabelTransliterationCheckBox->isChecked()) << 3 |
@@ -1245,6 +1533,45 @@ void ViewDialog::updateSkyCultureScreenStyleFromCheckboxes()
 				));
 }
 
+void ViewDialog::populateCulturalCombo(QComboBox *combo, StelObject::CulturalDisplayStyle style)
+{
+//Save the current selection to be restored later
+combo->blockSignals(true);
+//int index = combo->currentIndex();
+//QVariant selectedStyle = combo->itemData(index);
+combo->clear();
+//Allow only single-style for space reasons, and store the key as user data.
+combo->addItem(qc_("native",          "cultural style"), QVariant::fromValue(StelObject::CulturalDisplayStyle::Native));
+combo->addItem(qc_("transliteration", "cultural style"), QVariant::fromValue(StelObject::CulturalDisplayStyle::Pronounce));
+combo->addItem(qc_("sci. translit.",  "cultural style"), QVariant::fromValue(StelObject::CulturalDisplayStyle::Translit));
+combo->addItem(qc_("translated",      "cultural style"), QVariant::fromValue(StelObject::CulturalDisplayStyle::Translated));
+//Restore the selection
+int index = combo->findData(QVariant::fromValue(style), Qt::UserRole, Qt::MatchCaseSensitive);
+combo->setCurrentIndex(index);
+combo->blockSignals(false);
+}
+
+// called from the ZodiacDisplayStyle combo. int is the newly selected index.
+void ViewDialog::setZodiacLabelStyle(int index)
+{
+	static StelSkyCultureMgr *scMgr       = GETSTELMODULE(StelSkyCultureMgr);
+
+	QComboBox *combo=static_cast<QComboBox *>(sender());
+	QVariant selectedStyle = combo->itemData(index);
+	StelObject::CulturalDisplayStyle style=selectedStyle.value<StelObject::CulturalDisplayStyle>();
+	scMgr->setZodiacLabelStyle(style);
+}
+
+void ViewDialog::setLunarSystemLabelStyle(int index)
+{
+	static StelSkyCultureMgr *scMgr       = GETSTELMODULE(StelSkyCultureMgr);
+
+	QComboBox *combo=static_cast<QComboBox *>(sender());
+	QVariant selectedStyle = combo->itemData(index);
+	StelObject::CulturalDisplayStyle style=selectedStyle.value<StelObject::CulturalDisplayStyle>();
+	scMgr->setLunarSystemLabelStyle(style);
+}
+
 void ViewDialog::skyCultureChanged()
 {
 	QListWidget* l = ui->culturesListWidget;
@@ -1422,7 +1749,6 @@ void ViewDialog::updateDefaultSkyCulture()
 	ui->rayHelperThicknessSpinBox->setEnabled(b);
 	ui->colorRayHelpers->setEnabled(b);
 	ui->asterismsFontSizeSpinBox->setEnabled(b);
-	ui->constellationPickCheckBox->setEnabled(b);
 }
 
 void ViewDialog::updateDefaultLandscape()
